/* hfcl_hand_timer_trace.h
 * Copyright (C) 2007, Hitachi, Ltd.
 * Author(s): Yoshihiro Toyohara <yoshihiro.toyohara.qs@hitachi.com>
 */
/*
 * $Id: hfcl_hand_timer_trace.h,v 1.7.2.7 2007/12/12 02:55:04 eteshima Exp $
 */

/*--- TRACE ID ---------------------*/

#define HFC_TRC_HANDLER         0x91
#define HFC_TRC_MBRESP          0x92
#define HFC_TRC_MBINT           0x93
#define HFC_TRC_XRBRSP          0x94
#define HFC_TRC_SCSI_CHK        0x95
#define HFC_TRC_MGM_CHK         0x96
#define HFC_TRC_LINK_CHK        0x97
#define HFC_TRC_CHKSTP          0x98
#define HFC_TRC_DEQ_WE          0x99
#define HFC_TRC_LINKRSP         0x9a
#define HFC_TRC_LGINRSP         0x9b
#define HFC_TRC_ABEND           0x9c
#define HFC_TRC_PDISCRSP        0x9d
#define HFC_TRC_MCKREC          0x9e
#define HFC_TRC_GIDFTRSP        0x9f
#define HFC_TRC_MIHLGRSP        0xa1
#define HFC_TRC_HWERR           0xa2
#define HFC_TRC_WDOG            0xa5
#define HFC_TRC_GPNIDRSP        0xa6
#define HFC_TRC_LINKDOWN_INT    0xa7
#define HFC_TRC_LINKUP_INT      0xa8
#define HFC_TRC_PLOGI_INT       0xa9
#define HFC_TRC_LOGO_INT        0xaa
#define HFC_TRC_SCN_INT         0xab
#define HFC_TRC_RSCN_INT        0xac
#define HFC_TRC_GIDPNRSP        0xad

/*--- hfc_reset_start() parm(type)  ----*/
#define HFC_CTLRST              0x01
#define HFC_REBOOT              0x02
#define HFC_F_START             0x03
#define HFC_FW_START            0x04
#define HFC_INI_RESET           0x05
#define HFC_SET_INIADR          0x06
#define HFC_SET_WS80            0x07
#define HFC_SET_WS40            0x08
#define HFC_WSCA_CLEAR          0x09
#define HFC_SET_WS04            0x0a

#define HFC_SET_MLPF_MODE       0x10    /* FCLNX-0379 */

/*--- type field ---*/
#define TYPE_0                  0x80
#define TYPE_0_PTY              0x81    /* FCWIN-0220 */
#define TYPE_1                  0x40
#define TYPE_01                 0xc0
#define TYPE_2                  0x20
#define TYPE_ELOG               0xf0 
#define TYPE_PCI                0xff
#define TYPE_CFG                0xfe
#define TYPE_TRC0               0xfd
#define TYPE_TRC1               0xfc
#define TYPE_ILS                0xfb
#define TYPE_SEQ                0xfa
#define TYPE_BCFG               0xf9
#define TYPE_EVT0               0x01
#define TYPE_EVT1               0x02    /* FCWIN-0220 STR*/
#define TYPE_EVT2               0x03
#define TYPE_EVT3               0x04
#define TYPE_FRM0               0x05
#define TYPE_FRM1               0x06
#define TYPE_FRM2               0x07
#define TYPE_FRM3               0x08
#define TYPE_ROTATE             0x10
#define TYPE_RSV                0x7f    /* FCWIN-0220 END*/
/*------------------*/
#define REG_RAMMSK              0x02f8
#define REG_RAMADR              0x02fc	
#define REG_INDAREA             0x0500

#define REG_INDFLASH            0x0500
#define REG_INDAREA_FIVE        0x0600  /* FCWIN-234 */

/*-----------------------------------------------------------------*/
/*                         trace format                            */
/* The member name of each structure uses the following prefixes   */
/*                                                                 */
/* a_   : Value acquired from member of adap_info                  */
/* t_   : Value acquired from member of target_info                */
/* s_   : Value acquired from member of Srb                        */
/* h_   : Value acquired from member of hfc_pkt                    */
/*                                                                 */
/*-----------------------------------------------------------------*/
struct errlog_t {
	uint	type;			/* Error type */
	char	errmsg[64];
};

struct hraslog_t {
	uint	type;			/* Error type */
	char	alart1[3];
	char	alart2[3];
};

struct hraslog_errid {
	uchar	ppid[4];
	uchar	alartcode[2];
	uchar	errno[2];
};

typedef struct mem_type {
	uchar	type ;
	uint	reg_adr ;
	uint	size ;
}Type_mem ;

struct hfc_err_head_plus{                           /*  FCWIN-0220 */
	struct hfc_err_head		head;
	uchar					hfc_drv_log[16];
	uint					type;
	uint					errno;
};                                                  /*  FCWIN-0220 */

#define     HFC_DUMP_DATA_NUM   16

struct err_trc1 {
	uchar				id ;
	uchar				sub_id ;
	uchar				resv1[2] ;
	uint				a_status ;
	uint64_t			a_scsi_id ;
	uint				int_a_reg;
	uchar				resv2[100];
	uint64_t			current_time;
};

struct err_trc2 {
	uchar				id;
	uchar				sub_id ;
	ushort				mb_retry_cnt ;
	uint				a_status ;
	uint64_t			a_scsi_id ;
	uint				passthrough_rsp;
	uchar				t_flags;
	uchar				t_pseq ;
	uchar				mb_status;
	uchar				resv1[1];
	uint				t_status;
	uint				t_id;
	uint64_t			a_next_tstart;
	uint64_t			t_ww_name;
	uint64_t			t_node_name;
	uchar				mb_resp[68];
	uint64_t			current_time;
};

struct err_trc3 {
	uchar				id;
	uchar				sub_id ;
	ushort				xrb_no ;
	uint				a_status ;
	uint64_t			a_scsi_id;
	uint				xrb_outp ;
	uint				xrb_inp ;
	ushort				xrb_cnt ;
	uchar				xrb[70] ;
	uchar				resv1[16] ;
	uint				adap_status;	/* */
	uint				xob_no;
	uint64_t			current_time;
};

struct err_trc4 {
	uchar				id;
	uchar				sub_id ;
	ushort				xrb_no ;
	uint				a_status ;
	uint64_t			a_scsi_id ;
	uint				t_status;
	uchar				t_flags;
	uchar				t_pseq ;
	uchar				fcp_status;
	uchar				scsi_status;
	uchar				t_wait_abort[32];
	uint64_t			srb;
	uchar				s_function;
	uchar				s_status;
	uchar				s_target;
	uchar				s_lun;
	uchar				s_quetag;
	uchar				s_queaction;
	uchar				s_cdblen;
	uchar				s_senselen;
	uint				s_flags;
	uint				s_datatransferlength;
	uint64_t			hfcp;
	uint				h_adap_status;
	uint				h_iov_no;
	uint				h_iov_cnt;
	uint				t_we_que_cnt;
	uint				result;
	uint				resid;
	uint				serial_number;
	uchar				resv1[4];
	uint64_t			current_time;
};

struct err_trc5 {
	uchar				id;
	uchar				sub_id;
	ushort				xrb_no;
	uint				a_status;
	uint64_t			a_scsi_id;
	uint				t_status;
	uchar				t_flags;
	uchar				t_pseq;
	ushort				timer_id;
	uint64_t			srb;
	uchar				s_function;
	uchar				s_status;
	uchar				s_target;
	uchar				s_lun;
	uchar				resv1[84];
	uint64_t			current_time;
};

struct err_trc6 {
	uchar				id;
	uchar				sub_id;
	uchar				resv1[2];
	uint				a_status ;
	uint64_t			a_scsi_id ;
	uint				int_a_reg;
	uint				 detail_reg;
	uint64_t			status_reg;
	uint				link_dead_cnt ;
	uint				pci_err_cnt ;
	uint				mck_err_cnt ;
	uchar				resv2[76] ;
	uint64_t			current_time;
};
