/*
 * hfcl_strategy.c
 * Copyright (C) 2007, Hitachi, Ltd.
 * Author(s): Yoshihiro Toyohara <yoshihiro.toyohara.qs@hitachi.com>
 */

char stra_rcsid[] = "$Id: hfcl_strategy.c,v 1.71.2.23.2.18.2.4 2008/08/28 12:09:22 toyo Exp $";

/* include File */

#include "hfcldd.h"
#include "hfcl_tbol.h"
#include "hfcl_detect.h"
#include "hfcl_mlpf.h"
#include "hfcl_strategy.h"
#include "hfcl_handler.h"
#include "hfcl_stra_trace.h"
#include "hfcl_timer_recovery.h"
#include "hfcl_top.h"
#include "hfcl_ioctl.h"
#include "hfcldd_conf.h"

/*-- global variable --*/


/*-- static --*/
static int hfc_resource_chk(struct adap_info *ap, 
	struct target_info *target,
	struct hfc_pkt *hfcp,
	uint   fw_xob_outp);

static void hfc_get_free_iov(struct adap_info *ap ,
	uint st_word,
	uint st_bit,
	uint req_bit_cnt,
	struct	free_iov_map *fmap);

static void hfc_iov_update(struct adap_info *ap ,
	uint pos ,
	uint cnt ,
	uchar type);

static int hfc_dma_map( struct adap_info *ap, 
	struct hfc_pkt *hfcp );

static void hfc_make_cmdiu( struct adap_info *ap, 
	struct hfc_pkt *hfcp );

static void hfc_xob_enque(struct adap_info *ap, 
	struct target_info *target,
	struct hfc_pkt *hfcp);

void hfc_enque_next_dstart(struct adap_info *ap,
	struct target_info *target);

static void hfc_cancel_tskmgm(struct adap_info *ap,
	struct target_info          *target,
	uchar                       lun,
	struct hfc_pkt              *hfcp,
	uint                        adap_status,
	uint                        type);

static void hfc_stra_trace(uchar id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3);
static void hfc_stra_trc1( uchar   *trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3);
static void hfc_stra_trc2( uchar   *trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3);
static void hfc_stra_trc3( uchar   *trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3);
static void hfc_stra_trc4( uchar   *trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3);
static void hfc_stra_trc5( uchar   *trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3);

#if 0 
	uchar trcbuf[128] ; /* trcbuf is used in hfc_seg_info_scatter() */
	void hfc_seg_info_scatter(struct adap_info *ap) ;
#endif

#if _HFC_ERROR_INJ									/* FCLNX-0246 */
extern int hfc_debug_ioerr_code;					/* FCLNX-0246 */
#endif												/* FCLNX-0246 */

#define XOB_SEGNUM                  2

extern struct narrow_dev hfc_narrow_dev;			/* FCLNX-0392 */
uchar	logdata[16] ;


/*
 * Function:    hfc_strategy
 *
 * Purpose:     Initiate SCSI command 
 *
 * Arguments:   
 *  cmnd		Pointer to Scsi_Cmnd
 *  iodone		Pointer to done() (Return SCSI response)
 *
 * Returns:     
 *  			0 :  Completed SCSI initiation successfully 
 *  			EIO : Adap_info or dev_info does not exist or invalid.
 * 				(Only for ioctl)
 *
 * Notes:       Caller should be in process level or interruption level.
 */
int hfc_strategy(struct scsi_cmnd *cmnd, void (*iodone)(struct scsi_cmnd *))
{
	if (( hfc_manage_info.lg_target_info == NULL ) || (!hfc_manage_info.hfcldd_mp_mod)) {
		return ( hfc_strategy_pg(cmnd,iodone) );
	} else {
		return ( hfc_manage_info.npubp->hfc_strategy_mp(cmnd,iodone) );
	}
}

int hfc_eh_abort(struct scsi_cmnd *cmnd)
{
	if (( hfc_manage_info.lg_target_info == NULL ) || (!hfc_manage_info.hfcldd_mp_mod)) {
		return ( hfc_eh_abort_pg(cmnd) );
	} else {
		return ( hfc_manage_info.npubp->hfc_mp_abort(cmnd) );
	}
}

int hfc_eh_device_reset(struct scsi_cmnd *cmnd)
{
	if (( hfc_manage_info.lg_target_info == NULL ) || (!hfc_manage_info.hfcldd_mp_mod)) {
		return ( hfc_eh_device_reset_pg(cmnd) );
	} else {
		return ( hfc_manage_info.npubp->hfc_mp_device_reset(cmnd) );
	}
}

int hfc_eh_bus_reset(struct scsi_cmnd *cmnd)
{
	if (( hfc_manage_info.lg_target_info == NULL ) || (!hfc_manage_info.hfcldd_mp_mod)) {
		return ( hfc_eh_bus_reset_pg(cmnd) );
	} else {
		return ( hfc_manage_info.npubp->hfc_mp_bus_reset(cmnd) );
	}
}

int hfc_strategy_pg(struct scsi_cmnd *cmnd, void (*iodone)(struct scsi_cmnd *))
{
	int		func_rc = 0 ;
	struct	adap_info	*ap ; 	
	struct	hfc_pkt		*hfcp = NULL;
	uint			result, ioctl_mode=0;
	unsigned long	flags = 0;														/* FCLNX-0274 */

	ap = (struct adap_info *) CMND_HOSTDATA(cmnd);

	hfcp = (struct hfc_pkt *)cmnd->host_scribble;
	if(hfcp != NULL)
	{
		if( test_bit(CFLAG_VALID, (ulong *)&hfcp->cmd_flags ) )
		{
			HFC_DBGPRT("hfcldd%d : hfc_strategy - scsi_cmnd retried\n", ap->dev_minor);
			return(0);
		}
	}

	cmnd->scsi_done = iodone;
	if( iodone == (void *) hfc_ioctl_iodone ) ioctl_mode=1;
	cmnd->result = 0;
	cmnd->resid = 0;
	
	if( ap == NULL ) 
	{
		
		if(ioctl_mode == 1) func_rc=EIO;
		result = DID_ERROR;
		cmnd->result |= ( result << 16);
		hfcp->adap_status = SCS_NO_ADAPINFO;			/* FCLNX-0534 */
		HFC_ERRPRT(" hfcldd : hfc_strategy - ap==NULL-error\n");

		cmnd->scsi_done(cmnd);
		return(func_rc);
	}

	HFC_ADAPLOCK_IRQSAVE(flags);

	ap->scsi_exec_cnt++;


	hfcp = hfc_get_new_hfcp(ap);
	if( hfcp == NULL){
		
		if(ioctl_mode == 1) func_rc=EIO;

		result = DID_BUS_BUSY;
		cmnd->result |= ( result << 16);
		hfcp->adap_status = SCS_NO_HFCPKT;		/* FCLNX-0534 */

		HFC_DBGPRT(" hfcldd : hfc_strategy - hfcp==NULL-error\n");

		ap->scsi_err_cnt++ ;
		ap->scsi_end_cnt++;
		hfc_iodone(ap, cmnd, NULL);
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
		return(func_rc);
	}

	memset(hfcp, 0, sizeof(struct hfc_pkt));
	set_bit(CFLAG_VALID, (ulong *)&hfcp->cmd_flags );
	ap->pkt_no++;
	if (ap->pkt_no >= ap->pkt_num) ap->pkt_no = 0;
	ap->pkt_cnt++;
	
	hfcp->cmd_pkt   = cmnd;
	hfcp->target_id = CMND_TARGET(cmnd);
	hfcp->lun_id    = CMND_LUN(cmnd);
	hfcp->ap        = ap;
	hfcp->target    = hfc_hash_target_valid(ap, CMND_TARGET(cmnd));
	hfcp->dev       = NULL;
	hfcp->group_id  = 0;
	hfcp->fail      = 0;
	cmnd->host_scribble = (void *)hfcp;

	func_rc = hfc_strategy_hfcp(hfcp);

	HFC_ADAPUNLOCK_IRQRESTORE(flags);
	return ( func_rc );
}


int hfc_strategy_hfcp(struct hfc_pkt *hfcp)
{
	int		func_rc = 0 ;
	struct	mp_adap_info *mpap;
	struct	adap_info	 *ap ; 				
	struct	target_info	 *target ;			
	struct	scsi_cmnd 	 *cmnd=hfcp->cmd_pkt;
	
	uint			lun,hit,entry;							  /* FCLNX-0392 */
	char			buf1[32],buf2[32];
	uint			result, ioctl_mode=0;

	ap = hfcp->ap;

	if( cmnd->scsi_done == (void *) hfc_ioctl_iodone ) ioctl_mode=1;
	
    mpap = ap->mp_adap_info;
	
	if( test_bit( HFC_DIAG_PROGRESS, (ulong *)&mpap->status ) )
	{
		/* Reject SCSI command while executing DIAG process */
		if(ioctl_mode == 1) func_rc=EIO;
		result = DID_ERROR;
		cmnd->result |= ( result << 16);
		hfcp->adap_status = SCS_REJCT_DIAG;					/* FCLNX-0534 */

		hfc_iodone(ap, cmnd, hfcp);
		return(func_rc);
    }
	
	/* 
	 *Check each element of Scsi_Cmnd structure 
	 */
	if(cmnd->transfersize > (uint)ap->dma_max)
	{
		result = DID_ERROR;
		cmnd->result |= ( result << 16);
		set_bit(CFLAG_INH_ALTPATH, (ulong *)&hfcp->cmd_flags);
		hfcp->adap_status = SCS_DMASIZE_OVER;					/* FCLNX-0534 */

		hfc_iodone(ap, cmnd, hfcp);
		return(0);
	}
	if ( (CMND_CHANNEL(cmnd) != 0)
	  || (CMND_TARGET(cmnd) >= ap->max_target)
	  || (CMND_TARGET(cmnd) == ap->hosts->this_id)				/* FCLNX-0405 */
	  || (CMND_LUN(cmnd) >= MAX_DEV_CNT) ) {
		result = DID_BAD_TARGET;
		cmnd->result |= ( result << 16);
		set_bit(CFLAG_INH_ALTPATH, (ulong *)&hfcp->cmd_flags);
		hfcp->adap_status = SCS_TARGET_NOTFOUND;					/* FCLNX-0534 */

		hfc_iodone(ap, cmnd, hfcp);
		return(0);
	}
	if(cmnd->cmd_len > 16)
	{
		result = DID_ERROR;
		cmnd->result |= ( result << 16);
		set_bit(CFLAG_INH_ALTPATH, (ulong *)&hfcp->cmd_flags);
		hfcp->adap_status = SCS_CMDLENGTH_OVER;	/* FCLNX-0534 */

		hfc_iodone(ap, cmnd, hfcp);
		return(0);
	}
	
	lun = hfcp->lun_id;

	if(!(test_bit(HFC_ATTACH, (ulong *)&ap->attach_status ) ) )
    {
		/* Adapter is not intialized */
		if(ioctl_mode == 1) func_rc=EIO;
		result = DID_ERROR;
		cmnd->result |= ( result << 16);
		hfcp->adap_status = SCS_ATTATCH_ERROR;	/* FCLNX-0534 */

		HFC_DBGPRT(" hfcldd : hfc_strategy - ap->attach_status-error\n");		/* FCLNX-0244 */

		ap->scsi_err_cnt++ ;

		hfc_iodone(ap, cmnd, hfcp);
		return(func_rc);
    }
	
	if( !( test_bit( HFC_ONLINE, (ulong *)&ap->status ) ) )
	{
		/* Adapter is not ONLINE */
		if(ioctl_mode == 1) func_rc=EIO;
		result = DID_NO_CONNECT;
		cmnd->result |= (result << 16);
		ap->scsi_err_cnt++ ;
		hfcp->adap_status = SCS_ADAPTER_OFFLINE;	/* FCLNX-0534 */
		
		hfc_iodone(ap, cmnd, hfcp);
		return(func_rc);
	}
	
	target = hfcp->target;
	
	/* Is Target initiated? */
	if(target == NULL)
	{
		if(ioctl_mode == 1) func_rc=EIO;
		result = DID_BAD_TARGET;
		cmnd->result |= ( result << 16);

		hfcp->adap_status = SCS_NO_TARGET;
		
		hfc_stra_trace(HFC_TRC_STRATEGY ,0x31 ,ap , target, hfcp, (ulong)cmnd, 0,0);
		hfc_iodone(ap, cmnd, hfcp);
		return(func_rc);
	} 
	else if(!(HFC_TG_FLAGS_TEST( HFC_WWN_VALID, target )))
	{
		if(ioctl_mode == 1) func_rc=EIO;
		result = DID_NO_CONNECT;
		cmnd->result |= ( result << 16);
		hfcp->adap_status = SCS_WWN_INVALID;
		
		HFC_DBGPRT(" hfcldd : hfc_strategy - target->flags<HFC_WWN_VALID>=0. \n");
		
		hfc_stra_trace(HFC_TRC_STRATEGY ,0x32 ,ap , target, hfcp, (ulong)cmnd, 0,0);
		hfc_iodone(ap, cmnd, hfcp);
		return(func_rc);
	}
	
	if (ap->narrowmap == 1) {						/* DPM mode */	/* FCLNX-0392 */
		hit=0;
		for (entry=0;entry<8;entry++) {
			if ((ap->boot_priority[entry].ww_name == hfcp->target->ww_name)
			 && (ap->boot_priority[entry].lun     == hfcp->lun_id) ) {
				hit = 1;
				break;
			}
		}
		
		if (hit) {
			hit=0;
			
			if ( (ioctl_mode == 1) && (!hfc_narrow_dev.ap.ww_name
			 || (hfc_narrow_dev.ap.bus > ap->pci_cfginf->bus->number)
			 || ((hfc_narrow_dev.ap.bus == ap->pci_cfginf->bus->number)
			     && (hfc_narrow_dev.ap.devfn > ap->pci_cfginf->devfn))
			 || ((hfc_narrow_dev.ap.bus == ap->pci_cfginf->bus->number)
			     && (hfc_narrow_dev.ap.devfn == ap->pci_cfginf->devfn)
				 && (hfc_narrow_dev.priority > entry))) ) {

				hfc_narrow_dev.ap.ww_name   = ap->ww_name;
				hfc_narrow_dev.ap.bus       = ap->pci_cfginf->bus->number;
				hfc_narrow_dev.ap.devfn     = ap->pci_cfginf->devfn;
				hfc_narrow_dev.priority     = entry;
				hfc_narrow_dev.tgt.ww_name  = hfcp->target->ww_name;
				hfc_narrow_dev.tgt.lun      = hfcp->lun_id;
				hit=1;
				sprintf(buf1,"%llx", (unsigned long long)hfc_narrow_dev.tgt.ww_name);
				sprintf(buf2,"%x", hfc_narrow_dev.tgt.lun);

				HFC_INFPRT("hfcldd%d : narrow mode(lun) - HBA WWPN=%llx(%02x:%02x.%x), Priority=%d, Target WWPN,LU=%s,%s\n",
							ap->dev_minor,
							(unsigned long long) hfc_narrow_dev.ap.ww_name,
							ap->pci_cfginf->bus->number, 
							PCI_SLOT(ap->pci_cfginf->devfn),
							PCI_FUNC(ap->pci_cfginf->devfn),
							hfc_narrow_dev.priority,
							buf1,
							buf2 );
			}
			else {
				if ( (hfc_narrow_dev.ap.ww_name  == ap->ww_name)
				   && (hfc_narrow_dev.tgt.ww_name == hfcp->target->ww_name)
				   && (hfc_narrow_dev.tgt.lun     == hfcp->lun_id) ) {
					hit=1;
				}
			}
		}
		
		if (!hit && !ioctl_mode) {
			result = DID_BAD_TARGET;
			cmnd->result |= ( result << 16);
			hfcp->adap_status = SCS_NARROW_DEV;
			
			set_bit(CFLAG_INH_ALTPATH, (ulong *)&hfcp->cmd_flags);
			
			hfc_stra_trace(HFC_TRC_STRATEGY ,0x33 ,ap , target, hfcp, (ulong)cmnd, 0,0);
			hfc_iodone(ap, cmnd, hfcp);
			return(func_rc);
		}
	}																/* FCLNX-0392 */

	if ( !test_bit(CFLAG_ABORT, (ulong *)&hfcp->cmd_flags )
	  && !test_bit(CFLAG_LUN_RESET, (ulong *)&hfcp->cmd_flags ) 
	  && !test_bit(CFLAG_TARGET_RESET, (ulong *)&hfcp->cmd_flags ) 
	  && !test_bit(CFLAG_BUS_RESET, (ulong *)&hfcp->cmd_flags )
	  && !test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags) ) {
//		hfc_watchdog_enter( ap,target, hfcp, 0,HFC_SCSI_CMD_TMR,hfcp->cmd_pkt->timeout_per_command,FALSE );	/* FCLNX-0521 */

		if (!ioctl_mode && cmnd->eh_timeout.function) {					/* FCLNX-0269 */
//			if( ap->scsi_time_out ){
//				mod_timer( &cmnd->eh_timeout, (jiffies + ((cmnd->timeout_per_command/HZ)
//							+ HFC_ABORT_ACA_TO + HFC_ELS_TO + (HFC_MCKINT_TO*2) + 2)*HZ) );
//			}
//			else{
//				mod_timer( &cmnd->eh_timeout, ( jiffies + ( (cmnd->timeout_per_command/HZ)
//							+ (HFC_ABORT_ACA_TO + HFC_ELS_TO*4 + HFC_MCKINT_TO + HFC_LINKUP2_TO)*10 )*HZ ) );
//			}

			mod_timer( &cmnd->eh_timeout, ( jiffies + ( (cmnd->timeout_per_command/HZ) + 60*60)*HZ ) );	/* FCLNX-0521 */
		}																/* FCLNX-0287 */
	}

	hfcp->target = target;
	hfc_enqueue_wx_que(target, hfcp);

	hfc_stra_trace(HFC_TRC_STRATEGY ,0x20 ,ap , target, hfcp, (ulong)cmnd, 0, 0);

	/* Start SCSI command if target is valid */
	if(  !( test_bit( HFC_WAIT_LINK_INIT, (ulong *)&ap->status ))
	  && !( test_bit( HFC_WAIT_LINKUP, (ulong *)&ap->status ))
	  && !( test_bit( HFC_WAIT_BUSRSP, (ulong *)&ap->status ))
	  && !( test_bit( HFC_MCK_RECOVERY, (ulong *)&ap->status ))
	  &&  (target->status == HFC_NON_STATUS))
	{
		hfc_start( ap, target, hfcp) ;	
	}
	else
	{
		if(target->next_dstart_flag == 0)					/* FCLNX-GPL-046 */
		{
			hfc_enque_next_dstart(ap,target);				/* FCLNX-GPL-046 */
		}
		if(  ( test_bit( HFC_WAIT_LINK_INIT, (ulong *)&ap->status ))
		  || ( test_bit( HFC_WAIT_LINKUP, (ulong *)&ap->status ))
		  || ( test_bit( HFC_WAIT_BUSRSP, (ulong *)&ap->status ))
		  || ( test_bit( HFC_MCK_RECOVERY, (ulong *)&ap->status ))) {
			HFC_DBGPRT(" hfcldd : hfc_strategy_hfcp - wait ap->status = 0x%08x \n", ap->status);

			hfcp->adap_status = SCS_SCSI_DELAY;
			return(func_rc);
		}

		if( HFC_TG_STATUS_TEST( HFC_SCSI_DELAY, target ) )
		{
			HFC_DBGPRT(" hfcldd : hfc_strategy_hfcp - target : HFC_SCSI_DELAY\n");
			
			hfcp->adap_status = SCS_SCSI_DELAY;
			
			hfc_stra_trace(HFC_TRC_STRATEGY ,0x61 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
			return(func_rc);
		}
		
		if( HFC_TG_STATUS_TEST( HFC_SCN_WLINKUP, target ) )
		{
			HFC_DBGPRT(" hfcldd : hfc_strategy_hfcp - target : HFC_SCN_WLINKUP\n");
			
			hfcp->adap_status = SCS_SCSI_DELAY;
			
			hfc_stra_trace(HFC_TRC_STRATEGY ,0x65 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
			return(func_rc);
		}
		
		if( HFC_TG_STATUS_TEST( HFC_WAIT_DEVRSP, target ) )					/* FCLNX-0606 */
		{
			HFC_DBGPRT(" hfcldd : hfc_strategy_hfcp - target : HFC_WAIT_DEVRSP\n");
			
			hfcp->adap_status = SCS_SCSI_DELAY;
			
			hfc_stra_trace(HFC_TRC_STRATEGY ,0x66 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
			return(func_rc);
		}
		
		if( target->lustat[lun])
		{
			if(target->lustat[lun] & HFC_WAIT_ABORT)
			{
				HFC_DBGPRT(" hfcldd : hfc_strategy - lustat : HFC_WAIT_ABORT\n");

				if(ioctl_mode == 1) func_rc=EIO;

				hfcp->adap_status = SCS_CMD_ABORTED;
				hfc_stra_trace(HFC_TRC_STRATEGY ,0x45 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
				return(func_rc);
			}
			else if(target->lustat[lun] & HFC_NEED_ABORT)
			{
				HFC_DBGPRT(" hfcldd : hfc_strategy - lustat : HFC_NEED_ABORT\n");

				hfcp->adap_status = SCS_CMD_NEED_ABORT;
				hfc_stra_trace(HFC_TRC_STRATEGY ,0x46 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
				return(func_rc);
			}
		
			hfc_stra_trace(HFC_TRC_STRATEGY ,0x43 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
		}
		
		/* Check target status */
		if( HFC_TG_STATUS_TEST(HFC_WAIT_LOGIN, target))
		{
			hfcp->adap_status = SCS_WAIT_LOGIN;
			
			hfc_stra_trace(HFC_TRC_STRATEGY ,0x62 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
			return(func_rc);
		}
		
		/* Is target in NEED_LOGIN or WAIT_PDISC state? */
		if( (HFC_TG_STATUS_TEST( HFC_NEED_LOGIN, target ) ) && !( HFC_TG_STATUS_TEST( HFC_WAIT_PDISC, target) ) )
		{
			if( hfc_issue_relogin(ap,target) ) 
			{	/* LOGIN initiation failed*/
				HFC_DBGPRT( " hfcldd : hfc_strategy - re_login failed-error\n");
				
				hfc_stra_trace(HFC_TRC_STRATEGY ,0x51 ,ap ,target ,hfcp, (ulong)cmnd, 0, 0);
				return(func_rc);
			}
		}

		
		if( HFC_TG_STATUS_TEST( HFC_WAIT_TARGET_RESET, target ))
		{
			hfcp->adap_status = SCS_CMD_RESET;
			
			hfc_stra_trace(HFC_TRC_STRATEGY ,0x63 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
			return(func_rc);
		}

		/* XOB HALT */
		HFC_DBGPRT(" hfcldd : hfc_strategy - DID_BUS_BUSY\n");

		hfcp->adap_status = SCS_TARGET_ABNORMAL;

		hfc_stra_trace(HFC_TRC_STRATEGY ,0x64 ,ap ,target ,hfcp, (ulong)cmnd,
					 (unsigned long long)NULL,(unsigned long long)NULL);
		return(func_rc);
	}

	return(func_rc);

}  


/*
 * Function:    hfc_start
 *
 * Purpose:     Dequeue command from wait_xob_que and set it to xob, then start firmware.
 *              If xob initiation succeeds, enqueue it to wait_end_que.
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info
 *  pkt        - Pointer to hfc_pkt
 *
 * Returns:     
 *
 * Notes:       Caller should be process level or interrupt level.
 *              Lock adap_info before calling this function.
 *    
 */
int hfc_start(struct adap_info    *ap ,
               struct target_info  *target,
               struct hfc_pkt      *pkt)
{
	int		rc = 0 ;

	uchar	xob_empty = FALSE ;
	struct	scsi_cmnd	*cmnd=NULL ;
	uint	save_outp_num ,
			save_xob_page ,
			save_xob_entry,
			end_outp_num ;
	uint	chk_xob_outp = 0, fw_xob_outp, work_xob_outp;

	uint	xob_exec ;
	int		func_rc, lp=0, lun, ioctl_mode=0 ;
	uint	total_we_cnt = 0 ;
	uint	wk_finp, wk_cnt ;
	uchar	xob_lap = FALSE, strat_xob_cnt ;
	struct	target_info		*target_wk;
	struct	hfc_pkt		*hfcp, *hfcp_wk;
	int		result;
	uchar 	area;

	
	if(!(test_bit( HFC_ONLINE, (ulong *)&ap->status ) ) )
    {
		HFC_DBGPRT(" hfcldd : hfc_start - ap->status != HFC_ONLINE\n");

		hfc_errlog(ap,target,pkt,HFC_ERRLOG_TYPE_NONE,
							ERRID_HFCP_ERR9,0x04,NULL,0) ;
		return(FALSE) ;
	}

	if( test_bit( HFC_SCSI_DELAY, (ulong *)&target->status ) )
	{
		hfc_stra_trace(HFC_TRC_START ,0x61 ,ap , target, pkt, (ulong)cmnd, 0, 0);
		return(FALSE) ;
	}
	
	hfc_stra_trace(HFC_TRC_START,0x00, ap,target,NULL,(ulong)cmnd,0,0) ;

	/* 
	 * Repeat dequeuing command from Register wait_xob_queue and set it to xob 
	 * until wait_xob_queue is empty.
	 */
	 
	/* Setup hfc_pkt pointer */
	work_xob_outp = ap->fw_init_p->xob_outp;
	HFC_4B_TO_4L(fw_xob_outp, work_xob_outp);

	hfcp = target->wx_que_top;
	while( hfcp != NULL)
	{
		if ( hfc_manage_info.hfcldd_mp_mod && hfc_manage_info.lg_target_info) {
			if ( hfc_manage_info.npubp->hfc_queue_check(hfcp) ) {			/* FCLNX-0521 */
				hfcp_wk = hfcp->cmd_forw;
				hfcp = hfcp_wk;
//				printk(KERN_ERR "hfcldd%d hfc_queue_check()=1.\n", ap->dev_minor);
				continue;
			}
		}

		work_xob_outp = ap->fw_init_p->xob_outp;
		HFC_4B_TO_4L(fw_xob_outp, work_xob_outp);

		cmnd = hfcp->cmd_pkt;
		lun  = hfcp->lun_id;

		if(cmnd != NULL)
		{
			if( cmnd->scsi_done == (void *) hfc_ioctl_iodone ) ioctl_mode=1;
		}
		/* One or more commands exist in wait_xob_que */
		if( (rc = hfc_resource_chk(ap, target, hfcp, fw_xob_outp)) != 0 )
		{
			if( rc == HFC_PAGE_OVER )
			{
				/* Specified page is too large in number */
				if(ioctl_mode == 1) func_rc=EIO;
				result = DID_ERROR;
				cmnd->result |= ( result << 16);
				hfcp->adap_status = SCS_PAGE_OVER;		/* FCLNX-0534 */

				HFC_ERRPRT(" hfcldd : hfc_start - hfc_resource_chk = HFC_PAGE_OVER\n");
				ap->scsi_err_cnt++ ;
				
				/* Dequeue command from wait_xob_que */
				hfc_deque_wx_que(target, hfcp);
				hfc_iodone(ap, cmnd, hfcp);
							
				continue ;
			}
			
			if( rc != HFC_XOB_EMPTY )
			{
				/* Break the loop in case response is not XOB_EMPTY*/
				hfc_enque_next_dstart(ap,target) ;
				break ;
			}
			if(rc == HFC_IOVMAP_FULL)
			{
				HFC_DBGPRT(" hfcldd : hfc_start - hfc_resource_chk = HFC_IOVMAP_FULL\n");
			}
			/* Xob is empty */
			/* Save Xob_outp and clear start count */
			xob_empty = TRUE ;
			ap->xob_exec_cnt = 0 ;
			/* Use frame 4  */
			ap->frame_inp = 0 ;
			ap->frame_chkp = 0 ;
			ap->save_xob_outp[0] = fw_xob_outp;
		}
			
		/* Clear xob */
		HFC_BZERO(&ap->xob[ap->xob_no],sizeof(struct xob));	
		
		/* Map DMA area for data transfer */
		if(!(HFC_HFCP_CFLAG_TEST(CFLAG_SEGVALID, hfcp) ) )
		{
			if( (rc = hfc_dma_map(ap, hfcp)) != 0 )
			{
				if( rc == FAILED )  
					 /* No space for DMA. Break while loop */
				{
					HFC_ERRPRT(" hfcldd : hfc_start - hfc_dma_map = DMA_NORES | DMA_DIOFULL\n");

					/* 
					 * Check whether we_que is empty or not. 
					 * If no command exists in we_que, return EIO 
					 */
					total_we_cnt = 0 ;
					for(lp=0 ; lp<MAX_TARGET_PROBE ; lp++)
					{
						target_wk = hfc_hash_target_info(ap, lp);
						while( target_wk != NULL )
						{
							if( target_wk->we_que_cnt != 0 )
								total_we_cnt += target_wk->we_que_cnt ;
							target_wk = target_wk->next ;
						}
					}
					if( total_we_cnt == 0 )
					{
						result = DID_ERROR;
						cmnd->result |= ( result << 16);
						hfcp->adap_status = SCS_NO_WE_QUE;				/* FCLNX-0534 */

						HFC_ERRPRT(" hfcldd : hfc_start - total_we_cnt == 0\n");

						ap->scsi_err_cnt++ ;
						/* Dequeue command from wait_xob_que */
						hfc_deque_wx_que(target, hfcp);
						
						/* 
						 * If error occurs while handling task management command, 
						 * clear status flag
						 */
						if( (HFC_HFCP_CFLAG_TEST(CFLAG_TARGET_RESET, hfcp)) &&
							(HFC_TG_STATUS_TEST(HFC_WAIT_TARGET_RESET, target) ) )
							clear_bit(HFC_WAIT_TARGET_RESET, (ulong *)&target->status );
						else if( (HFC_HFCP_CFLAG_TEST(CFLAG_ABORT, hfcp)) &&
							(HFC_TG_STATUS_TEST(HFC_WAIT_ABORT, target) ) )
							clear_bit(HFC_WAIT_ABORT, (ulong *)&target->status );
						else if( (HFC_HFCP_CFLAG_TEST(CFLAG_BUS_RESET, hfcp)) &&
							(HFC_TG_STATUS_TEST(HFC_WAIT_BUS_RESET, target) ) )
							clear_bit(HFC_WAIT_BUS_RESET, (ulong *)&target->status );

						hfc_iodone(ap, cmnd, hfcp);

						hfc_stra_trace(HFC_TRC_START,0x80,
							ap,target,hfcp,(ulong)cmnd,0,0) ;
	
						continue ;
					}
					hfc_enque_next_dstart(ap,target) ;

					break ;
				}
			}
		}

		hfc_make_cmdiu( ap, hfcp );

		/* Setup Xob */
		hfcp_wk = hfcp->cmd_forw;
		hfc_xob_enque(ap, target, hfcp) ;
		
		if ( HFC_HFCP_CFLAG_TEST(CFLAG_ABORT, hfcp)				/* Abort Task Set */
		  || HFC_HFCP_CFLAG_TEST(CFLAG_LUN_RESET, hfcp) ) {		/* LUN reset */
				
				hfc_watchdog_enter( ap,target, hfcp, 0, HFC_ABORT_TMR,0,FALSE );
		}
		else if ( HFC_HFCP_CFLAG_TEST(CFLAG_TARGET_RESET, hfcp)	/* Target Reset from eh_device_reset */
			   || HFC_HFCP_CFLAG_TEST(CFLAG_BUS_RESET, hfcp) ) {/* Target Reset from eh_bus_reset */
				
				hfc_watchdog_enter( ap,target, hfcp, 0, HFC_TARGET_RST_TMR,0,FALSE );
		}
		else {
//			if ( test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags) )				/* FCLNX-0521 */
				hfc_watchdog_enter( ap,target, hfcp, 0, HFC_SCSI_CMD_TMR, hfcp->cmd_pkt->timeout_per_command, FALSE );
		}
		
		hfc_stra_trace(HFC_TRC_START,0x20,
				ap,target,hfcp,(unsigned long long)NULL, 0, 0) ;
		hfcp = hfcp_wk;
		
	}	

	/* Check commands in xob waiting for initiation */
	if( ap->xob_wait_exec_cnt == 0 )
 	{
		hfc_stra_trace(HFC_TRC_START,0x12,
				ap,target,NULL,(unsigned long long)NULL, 0, 0) ;
		hfc_enque_next_dstart(ap,target) ;								/* FCLNX-0105 */
		return(TRUE) ;
	}

	strat_xob_cnt = ap->xob_wait_exec_cnt;

	if( xob_empty == FALSE )
	{
		/* Caliculate the number of xobs in save_xob_outp */
		if( ap->frame_inp > ap->frame_chkp )
		{
			lp = ap->frame_inp - ap->frame_chkp;
		}
		else if( ap->frame_inp < ap->frame_chkp )
		{
			lp = ap->frame_inp + (MAX_FRAME_CNT - ap->frame_chkp) ;
		}
		else
		{
			lp = MAX_FRAME_CNT;
		}
		/* Check whether XOB queue is wraparound or not */
		chk_xob_outp = fw_xob_outp;
		/* 
		 * Compare current xob_outp with saved xob_outp and make sure that fw 
		 * have aldeay handled one or more xob in queue. 
		 */
		do 
		{
			area=TRUE;

			if( ap->save_xob_outp[ap->frame_chkp] > ap->xob_outp_end[ap->frame_chkp] )
				xob_lap = TRUE;
			else
				xob_lap = FALSE;

			/* 
			 * xob_outp > save_xob_outp	 
			 *  In this case FW have already handled one or more xob then 
			 *  check next xob_save_outp with incrementing ap->frame_chkp
			 * 
			 * Break from loop in case frame_inp = frame_chkp 
			 *  (This case has already checked)
			 */

			if(xob_lap != TRUE)
			{
				if( (chk_xob_outp < ap->save_xob_outp[ap->frame_chkp])
				 || (chk_xob_outp >= ap->xob_outp_end[ap->frame_chkp]) )
					area = FALSE;
			}
			else {
				if( (chk_xob_outp < ap->save_xob_outp[ap->frame_chkp])
				 && (chk_xob_outp >= ap->xob_outp_end[ap->frame_chkp]) )
					area = FALSE;
			}

			if (area == TRUE) {
				if( lp==MAX_FRAME_CNT ) { 
					/* The number of executing frame is full */
					hfc_stra_trace(HFC_TRC_START,0x13,
						ap,target,NULL, (unsigned long long)NULL, 0, 0);
					hfc_enque_next_dstart(ap,target) ;
					return(TRUE) ;
				}
				
				/* Check xob lap in frame */
				wk_finp = (ap->frame_inp) ? (ap->frame_inp-1) : (MAX_FRAME_CNT-1) ;
				save_outp_num = ((ap->save_xob_outp[ap->frame_chkp] & 0x00ff0000)>>16)*HFC_XOB_PER_PAGE ;
				save_outp_num += (ap->save_xob_outp[ap->frame_chkp] & 0x0000ffff) ;
				end_outp_num  = ((ap->xob_outp_end[wk_finp] & 0x00ff0000)>>16)*HFC_XOB_PER_PAGE ;
				end_outp_num  += (ap->xob_outp_end[wk_finp] & 0x0000ffff) ;
				
				if ( save_outp_num > end_outp_num )
					wk_cnt = ap->xob_max - (save_outp_num - end_outp_num);
				else
					wk_cnt = end_outp_num - save_outp_num;

				/* Limit executable xob number not to wraparound xob queue in save_xop_outp */
				if ((ap->xob_wait_exec_cnt + wk_cnt) > (ap->xob_max-1))
					strat_xob_cnt = (ap->xob_max-1) - wk_cnt;

				/* Limit executable xob number by half not to concentrate access in one frame */
				if (strat_xob_cnt > (ap->xob_max/2))
					strat_xob_cnt = (ap->xob_max/2);

				if ( strat_xob_cnt == 0 ) { 
					/* Unable to initiate frame */
					hfc_stra_trace(HFC_TRC_START,0x13,
						ap,target,NULL, (unsigned long long)NULL, 0, 0);
					hfc_enque_next_dstart(ap,target) ;
					return(TRUE) ;
				}

				break;
			}
			else
			{
				ap->frame_chkp++ ;
				if( ap->frame_chkp == MAX_FRAME_CNT )
					ap->frame_chkp = 0 ;
			}
			lp-- ;
		}while( lp ) ;
	}
	
	/*-- Collect bstart trace (Presence of F/W initiation) */

	
	/* Initiate XOB */
	/* Set XOB_ENQ command and the number of initiated XOB in frame A */
	xob_exec = 0 ;
	xob_exec = (uint) strat_xob_cnt ;
	xob_exec |= HFC_FRAMEA_ENQ_XOB ;

	hfc_write_reg(ap,( uint )HFC_IOSPACE_FRAMEA,( char )0x4, ( int )xob_exec );

	/*-- xob_outp format   --*/
	/*--   +0   : not used. --*/
	/*--   +1   : page_no --*/
	/*--   +2,3 : entry No.--*/

	if( xob_empty == TRUE )
	/* 
	 * Only reset flag here because initp->xob_outp is already set in save_xob_outp[0] 
	 * when xob is empty. 
	 */
	{
		xob_empty = FALSE ;
	}
	else
	{	
		/* 
		 * Caliculate sequential number of save_outp from page number and entry number
		 *
		 */
		if( ap->frame_inp == 0 )
			wk_finp = MAX_FRAME_CNT - 1 ;
		else
			wk_finp = ap->frame_inp - 1 ;
		
		ap->save_xob_outp[ap->frame_inp] = ap->xob_outp_end[wk_finp];
	}


	/*-----------------------------------------------------------------------------*/
	save_outp_num = ((ap->save_xob_outp[ap->frame_inp] & 0x00ff0000)>>16)*HFC_XOB_PER_PAGE ;
	save_outp_num += (ap->save_xob_outp[ap->frame_inp] & 0x0000ffff) ;
	/* 
	 * Caliculate sequential number of outp including xob_wait_exec_cnt.
	 */
	save_outp_num = (save_outp_num + strat_xob_cnt)%ap->xob_max;

	/* Convert sequential number into xob_outp format and set it to ap->xob_outp_end */ 

	save_xob_page = save_outp_num / HFC_XOB_PER_PAGE ;
	save_xob_entry = save_outp_num % HFC_XOB_PER_PAGE ;
	ap->xob_outp_end[ap->frame_inp] = ((save_xob_page << 16) & 0x00ff0000) | 
						(save_xob_entry & 0x0000ffff) ;
	ap->frame_inp++ ;
	if( ap->frame_inp == MAX_FRAME_CNT )
		ap->frame_inp = 0 ;
	/*-----------------------------------------------------------------------------*/


	ap->xob_exec_cnt = strat_xob_cnt ;
	ap->xob_wait_exec_cnt -= strat_xob_cnt ;
	
	if (ap->xob_wait_exec_cnt)											/* FCLNX-0105 STR*/
	{
		/* Several XOBs remain in queue */
		hfc_enque_next_dstart(ap,target) ;
	}																	/* FCLNX-0105 END*/
	
	hfc_stra_trace(HFC_TRC_START,0x10,
			ap, target, NULL, (unsigned long long)NULL, 0,0);
	
	return(TRUE) ;
}		


/*
 * Function:    hfc_get_new_hfcp
 *
 * Purpose:     Search empty hfc_pkt 
 *
 * Arguments:   
 *  ap          Pointer to adap_info
 *
 * Returns:     
 *
 * Notes:       
 */
struct hfc_pkt *
hfc_get_new_hfcp(struct adap_info *ap)
{
	int   i;
	struct hfc_pkt *hfcp;

	for (i=0;i<ap->pkt_num;i++)
	{
		hfcp = &ap->pkt_pool[ap->pkt_no / HFC_PKT_POOL_SIZE][ap->pkt_no % HFC_PKT_POOL_SIZE];	/* FCLNX-0521 */
		if(!(test_bit(CFLAG_VALID, (ulong *)&hfcp->cmd_flags)))
			return (hfcp);
		
		ap->pkt_no++;
		if (ap->pkt_no >= ap->pkt_num) 
			ap->pkt_no = 0;
	}

	return(NULL);
}


/*
 * Function:    
 *
 * Purpose:     Search empty dummy command 
 *
 * Arguments:   
 *  ap          Pointer to adap_info
 *
 * Returns:     
 *
 * Notes:       
 */
struct scsi_cmnd *
hfc_get_new_cmnd(struct adap_info *ap)
{
	int   i;

	for (i=0;i<ap->cmnd_num;i++)
	{
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,16)
		if(!(test_bit(CMND_VALID, (ulong *)&ap->cmnd_pool[ap->cmnd_no].sc_magic)))
#else
		if(!(test_bit(CMND_VALID, (ulong *)&ap->cmnd_pool[ap->cmnd_no].eh_eflags)))
#endif
			return (&ap->cmnd_pool[ap->cmnd_no]);
		
		ap->cmnd_no++;
		if (ap->cmnd_no >= ap->cmnd_num) 
			ap->cmnd_no = 0;
	}

	return(NULL);
}


/*
 * Function:    hfc_dummy_copy
 *
 * Purpose:     
 *
 * Arguments:   
 *  cmnd       -
 *  dummy_cmnd -
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_dummy_copy( struct scsi_cmnd *cmnd, struct scsi_cmnd *dummy_cmnd )
{
	dummy_cmnd->timeout_per_command = cmnd->timeout_per_command;
	dummy_cmnd->device = (struct scsi_device*)kmalloc(sizeof(struct scsi_device), GFP_ATOMIC);
	
	if(dummy_cmnd->device == NULL) 
	{
		return;
	}

	CMND_TARGET(dummy_cmnd) = CMND_TARGET(cmnd);

	CMND_LUN(dummy_cmnd) = CMND_LUN(cmnd);
	CMND_CHANNEL(dummy_cmnd) = CMND_CHANNEL(cmnd);

	dummy_cmnd->cmd_len = cmnd->cmd_len;
	dummy_cmnd->cmnd[0] = cmnd->cmnd[0];
	dummy_cmnd->sc_data_direction = cmnd->sc_data_direction;
	dummy_cmnd->scsi_done = cmnd->scsi_done;
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,16)
	set_bit(CMND_VALID, (ulong *)&dummy_cmnd->sc_magic );
#else
	set_bit(CMND_VALID, (ulong *)&dummy_cmnd->eh_eflags );
#endif
	
}

/*
 * Function:    hfc_eh_abort_pg
 *
 * Purpose:     Issue ABORT TASK SET
 *
 * Arguments:   
 *  cmnd       - Pointer to Scsi_Cmnd
 *
 * Returns:     
 *  SUCCESS    - Start succeeded
 *  FAILED     - Start failed
 *
 *
 * Notes:       
 */
int hfc_eh_abort_pg(struct scsi_cmnd *cmnd)
{
	struct	adap_info	*ap ;
	struct	target_info	*target ;
	struct hfc_pkt		*hfcp = NULL, *abort_pkt=NULL;
	struct scsi_cmnd	*dummy_cmnd=NULL;
	uint                lun,find;
	unsigned long		flags = 0;									/* FCLNX-0274 */

	/* Check argument(NULL?) */
	if( cmnd == NULL )
	{
		HFC_DBGPRT("hfcldd : hfc_eh_abort - invalid argument \n");
		return(FAILED);
    }

#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
	spin_lock_irq(cmnd->device->host->host_lock);
#endif

	ap = (struct adap_info *) CMND_HOSTDATA(cmnd);

	HFC_DBGPRT(" hfcldd%d : hfc_eh_abort - start channel=%d, tid=%d, lun=%d. \n",
					ap->dev_minor, CMND_CHANNEL(cmnd), CMND_TARGET(cmnd), CMND_LUN(cmnd));
	
	/* Check adap_info (NULL?) */
	if( ap == NULL )
	{
		HFC_DBGPRT("hfcldd : hfc_eh_abort - 1\n");
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
    }
    
    HFC_ADAPLOCK_IRQSAVE(flags);
	
	hfc_stra_trace(HFC_TRC_ABORT ,0x00 ,ap ,NULL , NULL, (ulong)cmnd, 0, 0);
	
	/* Find hfc_pkt */
	hfcp = (struct hfc_pkt *)cmnd->host_scribble;
	if( hfcp == NULL ){
		HFC_DBGPRT("hfcldd : hfc_eh_abort - already complete \n");
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(SUCCESS);
	}
	
	/* Check each element of scsi_cmnd structure */
	if ( (CMND_CHANNEL(cmnd) != 0)
	  || (CMND_TARGET(cmnd) >= ap->max_target)
	  || (CMND_TARGET(cmnd) == ap->hosts->this_id)
	  || (CMND_LUN(cmnd) >= MAX_DEV_CNT) )
	{
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}

	if ( !(test_bit(HFC_ATTACH, (ulong *)&ap->attach_status ) ) )
    {
		/* Adapter is not initialized */
		HFC_DBGPRT("hfcldd : hfc_eh_abort - not attach status \n");

		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
    }

	if ( !test_bit(HFC_ONLINE, (ulong *)&ap->status) )
	{
		/* Adapter is not online (link down) */
		HFC_DBGPRT("hfcldd : hfc_eh_abort - HFC_ONLINE=0 \n");
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(SUCCESS);
	}

	if( test_bit( HFC_WAIT_BUSRSP, (ulong *)&ap->status ) )
	{
		/* Adapter is executing BUS RESET */
		HFC_DBGPRT("hfcldd : hfc_eh_abort - exec bus reset\n");
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}

	target = hfc_hash_target_info(ap, CMND_TARGET(cmnd));
	lun = CMND_LUN(cmnd);

	/* Check target_info */
	if(target == NULL)
	{
		HFC_DBGPRT(KERN_ERR"hfcldd : hfc_eh_abort - target == NULL \n");

		hfc_stra_trace(HFC_TRC_ABORT ,0x31 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(SUCCESS);
	} 
	
	/* Target state is in NEED_LOGIN or PDISC is running */
	if (target->status)
	{
		/* target status is non zero */
		HFC_DBGPRT("hfcldd : hfc_eh_abort - target status non zero \n");
	
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}

	set_bit( CFLAG_TIMEOUT, (ulong *)&hfcp->cmd_flags );

	if (target->lustat[CMND_LUN(cmnd)] & (HFC_NEED_ABORT | HFC_WAIT_ABORT) )
	{
		/* Already issue abort task set */
		HFC_DBGPRT("hfcldd : hfc_eh_abort - HFC_WAIT_ABORT/HFC_NEED_ABORT \n");

		hfc_stra_trace(HFC_TRC_ABORT ,0x45 ,ap , target, hfcp, (ulong)cmnd, 0, 0);
		goto WAIT_ABORT_TS;
	}
	
	if( hfc_toutchk_xob(ap, target, hfcp, lun, HFC_ISSUE_ABORT) )
	{
		/* Timeout command remains in xob. */
		hfc_stra_trace(HFC_TRC_ABORT, 0x35, ap, target, hfcp, (ulong)cmnd, 0, 0);
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED); ;
	}

	if ( !test_bit(HFC_MCK_RECOVERY, (ulong *)&ap->status ) ) {	/* FCLNX-GPL-035 */
		if ( hfc_issue_mihlog( ap, target, hfcp ) == 0)
		{
			/* Initiate MIH-LOG successfully */
			HFC_DBGPRT("eh_abort mihlog successed. lun = %d \n",lun);
			target->lustat[lun] |= HFC_NEED_ABORT | HFC_DEFER_ABORT;

			hfc_stra_trace(HFC_TRC_ABORT, 0x70, ap, target, hfcp, (ulong)cmnd, 0, 0);
			goto WAIT_ABORT_TS;
		}
	}
	else {
		HFC_DBGPRT("skip eh_abort mihlog. lun = %d \n",lun);
	}																	/* FCLNX-GPL-035 */

	/* Initiate ABORT TASK SET */
	abort_pkt = hfc_get_new_hfcp(ap);
	if( abort_pkt == NULL)
	{
		/* Hfc_pkt is empty */
		HFC_DBGPRT(" hfcldd : hfc_eh_abort - hfcp==NULL-error\n");

		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}
	
	dummy_cmnd = hfc_get_new_cmnd(ap);
	if( dummy_cmnd == NULL )
	{
		/* Dummy scsi_cmnd is empty */
		HFC_DBGPRT(" hfcldd : hfc_eh_abort - dummy_cmnd==NULL-error\n");

		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}
	
	memset(abort_pkt, 0, sizeof(struct hfc_pkt));
	memset(dummy_cmnd, 0, sizeof(struct scsi_cmnd));

	set_bit(CFLAG_VALID, (ulong *)&abort_pkt->cmd_flags);
	set_bit(CFLAG_ABORT, (ulong *)&abort_pkt->cmd_flags);
	ap->pkt_no++;
	if (ap->pkt_no >= ap->pkt_num) ap->pkt_no = 0;
	ap->pkt_cnt++;

	abort_pkt->cmd_pkt   = dummy_cmnd;
	abort_pkt->target_id = CMND_TARGET(cmnd);
	abort_pkt->lun_id    = CMND_LUN(cmnd);
	abort_pkt->ap        = ap;
	abort_pkt->target    = target;
	abort_pkt->dev       = NULL;
	dummy_cmnd->host_scribble = (void *)abort_pkt;
	hfc_dummy_copy( cmnd, dummy_cmnd );
	ap->cmnd_no++;
	if (ap->cmnd_no >= ap->cmnd_num) ap->cmnd_no = 0;
	ap->cmnd_cnt++;

	hfc_enqueue_wx_que(target, abort_pkt);

	/* Issue SCSI command if target is normal */
	if(hfc_start( ap, target, abort_pkt)== TRUE)
	{
		target->lustat[lun] &= ~HFC_NEED_ABORT;
		target->lustat[lun] |= HFC_WAIT_ABORT;
		hfc_stra_trace(HFC_TRC_ABORT, 0x73, ap, target, abort_pkt, (ulong)dummy_cmnd, 0, 0);
	}
	else
	{	/* Failed to issue Abort Task Set because of resource busy */
		target->lustat[lun] |= HFC_NEED_ABORT;

		hfc_stra_trace(HFC_TRC_ABORT, 0x74, ap, target, abort_pkt, (ulong)dummy_cmnd, 0, 0);
	}
	
WAIT_ABORT_TS:

	HFC_DBGPRT("hfc_eh_abort : wait abort task set complete \n");

	do {
		find = FALSE;
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
		spin_unlock_irq(cmnd->device->host->host_lock);

		set_current_state(TASK_UNINTERRUPTIBLE);
		schedule_timeout(HZ/10+1);					/* Wait 100ms */

		spin_lock_irq(cmnd->device->host->host_lock);
		HFC_ADAPLOCK_IRQSAVE(flags);

		if ( (target->lustat[lun] & HFC_NEED_ABORT)
		  || (target->lustat[lun] & HFC_WAIT_ABORT) )
			find = TRUE;

	} while (find != FALSE);

	hfc_stra_trace(HFC_TRC_ABORT ,0x10 ,ap ,target ,abort_pkt, (ulong)dummy_cmnd, 0, 0);
	HFC_DBGPRT("hfcldd : hfc_eh_abort - end\n");
	if( (test_bit(HFC_NEED_LOGIN, (ulong *)&target->status ))||
		(test_bit(HFC_WAIT_LOGIN, (ulong *)&target->status ))||
		(test_bit(HFC_NEED_CANCEL, (ulong *)&target->status ))||		/* FCLNX-GPL-038 */
		(test_bit(HFC_WAIT_CANCEL, (ulong *)&target->status )))			/* FCLNX-GPL-038 */
	{
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}
	HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
	return(SUCCESS);
//	return(FAILED); /* Error injection */
}    

/*
 * Function:    hfc_eh_device_reset_pg
 *
 * Purpose:     Issue LOGIN to reset the specified target.
 *
 * Arguments:   
 *  cmnd        Pointer to Scsi_Cmnd
 *
 * Returns:     
 *  SUCCESS     Start succeeded
 *  FAILED      Start failed *
 * Notes:       
 */
int hfc_eh_device_reset_pg(struct scsi_cmnd *cmnd)
{
	struct	adap_info	*ap ;
	struct	target_info	*target ;
	struct hfc_pkt		*reset_pkt=NULL;
	int                 rtn;
	unsigned long		flags = 0;										/* FCLNX-0274 */
	struct scsi_cmnd 	*dummy_cmnd=NULL;

	/*-- check argument(NULL?) --*/
	if( cmnd == NULL )
	{
		/*-- invalid argument --*/
		HFC_DBGPRT("hfcldd : hfc_device_reset - invalid argument \n");
		return(FAILED);
    }

#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
	spin_lock_irq(cmnd->device->host->host_lock);
#endif

	ap = (struct adap_info *) CMND_HOSTDATA(cmnd);

	HFC_DBGPRT(" hfcldd%d : hfc_eh_device_reset - start channel=%d, tid=%d. \n",
						ap->dev_minor, CMND_CHANNEL(cmnd), CMND_TARGET(cmnd));

	if( ap == NULL )
	{
		HFC_DBGPRT("hfcldd : hfc_eh_device_reset - 1\n");
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
    }

	HFC_ADAPLOCK_IRQSAVE(flags);
	hfc_stra_trace(HFC_TRC_RESET ,0x00 ,ap ,NULL , NULL, (ulong)cmnd, 0, 0);

	/* Check scsi_cmnd structure */
	if ( (CMND_CHANNEL(cmnd) != 0)
	  || (CMND_TARGET(cmnd) >= ap->max_target)
	  || (CMND_TARGET(cmnd) == ap->hosts->this_id) )
	{
		HFC_DBGPRT("hfcldd : hfc_eh_device_reset - 3\n");
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}


	if ( !test_bit(HFC_ATTACH, (ulong *)&ap->attach_status ) )
    {
		HFC_DBGPRT("hfcldd : hfc_eh_device_reset - not attach status \n");
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
    }
    
	target = hfc_hash_target_info(ap, CMND_TARGET(cmnd));

	if ( !ap->enable_tgtrst )
	{	/* LOGIN Mode */
		if( ( test_bit( HFC_MCK_RECOVERY, (ulong *)&ap->status ) )
			|| ( !test_bit( HFC_ONLINE, (ulong *)&ap->status ) )
			|| ( test_bit( HFC_WAIT_LINKUP, (ulong *)&ap->status ) ) )
		{
			/* Executing machine check recovery */
			HFC_DBGPRT("hfcldd : hfc_eh_device_reset - mck recovery / link down \n");
			hfc_stra_trace(HFC_TRC_RESET,0x20, ap, target, NULL, (ulong)cmnd, 0, 0);
			
			HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
			spin_unlock_irq(cmnd->device->host->host_lock);
#endif
			return(SUCCESS);
		}
	}
	else 
	{	/* Target Reset Mode */
		if( !test_bit( HFC_ONLINE, (ulong *)&ap->status ) )
		{
			/* Executing machine check recovery */
			HFC_DBGPRT("hfcldd : hfc_eh_device_reset - Link Down \n");
			hfc_stra_trace(HFC_TRC_RESET,0x21, ap, target, NULL, (ulong)cmnd, 0, 0);
			
			HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
			spin_unlock_irq(cmnd->device->host->host_lock);
#endif
			return(FAILED);
		}
	}
	
	if( test_bit( HFC_WAIT_BUSRSP, (ulong *)&ap->status ) )
	{
		HFC_DBGPRT("hfcldd : hfc_eh_device_reset - already reset bus \n");

		hfc_stra_trace(HFC_TRC_RESET ,0x30 , ap, target, NULL, (ulong)cmnd, 0, 0) ;
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}
	

	if (target == NULL)
	{
		HFC_DBGPRT("hfcldd : hfc_eh_device_reset - 10\n");
		hfc_stra_trace(HFC_TRC_RESET ,0x31 ,ap , target, NULL, (ulong)cmnd, 0, 0);

		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(SUCCESS);
	}
	
	if ( HFC_TG_STATUS_TEST(HFC_WAIT_DEVRSP, target) )
	{
		HFC_DBGPRT("hfcldd : hfc_eh_device_reset - 13\n");

		hfc_stra_trace(HFC_TRC_RESET ,0x34 ,ap , target, NULL, (ulong)cmnd, 0, 0);
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(SUCCESS);
	}
	
	set_bit( HFC_WAIT_DEVRSP, (ulong *)&target->status );
	
	/* Cancel wait queue of SCSI command and Task Management */
	hfc_cancel_scsi_cmd(ap,target,0,NULL,SCS_WAIT_BUS_RESET, HFC_CSCSI_RESET,
			FALSE,TRUE, HFC_FLASH_TARGET );

	if ( !ap->enable_tgtrst )
	{
		hfc_stra_trace(HFC_TRC_RESET, 0x76, ap, target, NULL, (ulong)cmnd, 0, 0);

		if ( !test_bit(HFC_WAIT_LOGIN, (ulong *)&target->status) )
		{
		
			if( (test_bit(HFC_SCN_WLINKUP,(ulong *)&target->status))
			  &&(!test_bit(HFC_WAIT_CANCEL, (ulong *)&target->status) ) ){			/* FCLNX-GPL-038 */
				set_bit(HFC_NEED_CANCEL, (ulong *)&target->status);
				clear_bit(HFC_NEED_LOGIN, (ulong *)&target->status);				/* FCLNX-GPL-038 */
			}

			if ( hfc_issue_relogin(ap,target) )
			{
				HFC_DBGPRT("hfcldd : hfc_eh_device_reset - wait issue LOGIN \n");
//				set_bit( HFC_NEED_LOGIN, (ulong *)&target->status );				/* FCLNX-GPL-038 */
				hfc_enque_login_req(ap, target);
		
				hfc_stra_trace(HFC_TRC_RESET, 0x77, ap, target, NULL, (ulong)cmnd, 0, 0);
			}
		}
	}
	else
	{
		reset_pkt = hfc_get_new_hfcp(ap);
		if( reset_pkt == NULL )
		{
			/* No reserved space for hfc_pkt */
			HFC_DBGPRT(" hfcldd : hfc_device_reset - hfcp==NULL-error\n");
			
			set_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );			/* FCLNX-GPL-036 */
			hfc_watchdog_enter(ap, target, NULL, 0, HFC_RESTART_TMR, (HZ/100+1), TRUE);	/* FCLNX-GPL-036 */
			hfc_watchdog_enter(ap, target, NULL, 0, HFC_RESTART_TMR, (HZ/100+1), FALSE);
			goto WAIT_DEV_RST;
		}
		
		dummy_cmnd = hfc_get_new_cmnd(ap);
		if( dummy_cmnd == NULL)
		{
			/* No reserved space for scsi_cmnd structure */
			HFC_DBGPRT(" hfcldd : hfc_device_reset - dummy_cmnd==NULL-error\n");
			
			set_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );			/* FCLNX-GPL-036 */
			hfc_watchdog_enter(ap, target, NULL, 0, HFC_RESTART_TMR, (HZ/100+1), TRUE);	/* FCLNX-GPL-036 */
			hfc_watchdog_enter(ap, target, NULL, 0, HFC_RESTART_TMR, (HZ/100+1), FALSE);
			goto WAIT_DEV_RST;
		}

		memset(reset_pkt, 0, sizeof(struct hfc_pkt));
		memset(dummy_cmnd, 0, sizeof(struct scsi_cmnd));

		set_bit(CFLAG_VALID, (ulong *)&reset_pkt->cmd_flags);
		set_bit(CFLAG_TARGET_RESET, (ulong *)&reset_pkt->cmd_flags);
		ap->pkt_no++;
		if (ap->pkt_no >= ap->pkt_num) ap->pkt_no = 0;
		ap->pkt_cnt++;

		reset_pkt->cmd_pkt   = dummy_cmnd;
		reset_pkt->target_id = CMND_TARGET(cmnd);
		reset_pkt->lun_id    = 0;
		reset_pkt->ap        = ap;
		reset_pkt->target    = target;
		reset_pkt->dev       = NULL;
		dummy_cmnd->host_scribble = (void *)reset_pkt;
		hfc_dummy_copy( cmnd, dummy_cmnd );
		ap->cmnd_no++;
		if (ap->cmnd_no >= ap->cmnd_num) ap->cmnd_no = 0;
		ap->cmnd_cnt++;

		hfc_enqueue_wx_que(target, reset_pkt);
		
		/* Initiate Target Reset */
		if( hfc_start( ap, target, reset_pkt) == TRUE )
		{
			clear_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );			/* FCLNX-GPL-036 */
			set_bit( HFC_WAIT_TARGET_RESET, (ulong *)&target->status );
			hfc_stra_trace(HFC_TRC_RESET, 0x73, ap, target, reset_pkt, (ulong)dummy_cmnd, 0, 0);
		}
	}


WAIT_DEV_RST :
	HFC_DBGPRT("hfc_eh_device_reset : wait LOGIN complete \n");

	while (1) {
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
		spin_unlock_irq(cmnd->device->host->host_lock);

		set_current_state(TASK_UNINTERRUPTIBLE);
		schedule_timeout(HZ/10+1);					/* Wait 100ms */

		spin_lock_irq(cmnd->device->host->host_lock);
		HFC_ADAPLOCK_IRQSAVE(flags);

		if ( !test_bit(HFC_TARGETINF_VALID, (ulong *)&target->flags)
		  || !test_bit(HFC_DEVFLG_VALID, (ulong *)&target->flags)
		  || !test_bit(HFC_WWN_VALID, (ulong *)&target->flags)  )
		{
			rtn = SUCCESS;							/* FCLNX-0500 */
			break;
		}

		if ( !test_bit(HFC_NEED_LOGIN, (ulong *)&target->status)
		 &&  !test_bit(HFC_WAIT_LOGIN, (ulong *)&target->status) 
		 &&  !test_bit(HFC_NEED_CANCEL, (ulong *)&target->status)		/* FCLNX-GPL-038 */
		 &&  !test_bit(HFC_WAIT_CANCEL, (ulong *)&target->status) )		/* FCLNX-GPL-038 */
		{
			if (!ap->enable_tgtrst)
			{
				rtn = SUCCESS;
				break;
			}
			else
			{
				if ( !test_bit(HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset)		/* FCLNX-GPL-036 */
				 &&  !test_bit(HFC_WAIT_TARGET_RESET, (ulong *)&target->status) ) 
				{
					rtn = SUCCESS;
					break;
				}
			}
		}
	}

	clear_bit(HFC_WAIT_DEVRSP, (ulong *)&target->status);
	HFC_DBGPRT("hfcldd : hfc_eh_device_reset - end \n");
	
	hfc_stra_trace(HFC_TRC_RESET, 0x10, ap, target, NULL, (ulong)cmnd, 0, 0);
	HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
	spin_unlock_irq(cmnd->device->host->host_lock);
#endif
	return(rtn);
}    


/*
 * Function:    hfc_eh_bus_reset_pg
 *
 * Purpose:     Issue LOGIN to reset all targets 
 *
 * Arguments:   
 *  cmnd        Pointer to Scsi_Cmnd
 *
 * Returns:     
 *  SUCCESS     Start succeeded
 *  FAILED      Start failed 
 * Notes:       
 */int hfc_eh_bus_reset_pg(struct scsi_cmnd *cmnd)
{
	struct adap_info	*ap ;
	struct target_info	*target, *tgt=NULL ;
	struct hfc_pkt		*reset_pkt = NULL;
	int					lp;
	unsigned long		flags = 0;										/* FCLNX-0274 */
	uchar bus_reset_imcomplete = FALSE;
	uchar				find;
	struct scsi_cmnd 	*dummy_cmnd=NULL;

	HFC_DBGPRT(" hfcldd : hfc_eh_bus_reset - start channel=%d. \n" ,CMND_CHANNEL(cmnd));

	/*-- Check argument(NULL?) --*/
	if( cmnd == NULL )
	{
		HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - invalid argument \n");
		return(FAILED);
    }

#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
	spin_lock_irq(cmnd->device->host->host_lock);
#endif

	ap = (struct adap_info *) CMND_HOSTDATA(cmnd);

	if ( ap == NULL )
	{
		HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - invalid adap_info pointer \n");
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}

    HFC_ADAPLOCK_IRQSAVE(flags);

	hfc_stra_trace(HFC_TRC_BUS_RESET ,0x00 ,ap ,NULL , NULL, (ulong)cmnd, 0, 0);

	if (CMND_CHANNEL(cmnd) != 0)
	{
		/* Channel number is invalid */
		HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - invalid channel number \n");
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
	}
	
	if( !test_bit(HFC_ATTACH, (ulong *)&ap->attach_status ) )
    {
		HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - not attach status \n");
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(FAILED);
    }

	if ( !ap->enable_tgtrst )
	{
		if( ( test_bit( HFC_MCK_RECOVERY, (ulong *)&ap->status ) )
			|| ( !test_bit( HFC_ONLINE, (ulong *)&ap->status ) )
			|| ( test_bit( HFC_WAIT_LINKUP, (ulong *)&ap->status ) ) )
		{
			HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - Link Down \n");
			hfc_stra_trace(HFC_TRC_BUS_RESET,0x31, ap,NULL, NULL, (ulong)cmnd, 0, 0);

			HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
			spin_unlock_irq(cmnd->device->host->host_lock);
#endif
			return(SUCCESS);
    	}
	}
	else {
		if( !test_bit( HFC_ONLINE, (ulong *)&ap->status ) )
		{
			HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - Link Down in Target Reset \n");
			hfc_stra_trace(HFC_TRC_BUS_RESET,0x32, ap,NULL, NULL, (ulong)cmnd, 0, 0);
			
			HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
			spin_unlock_irq(cmnd->device->host->host_lock);
#endif
			return(FAILED);
		}
	}
	
	if( test_bit( HFC_WAIT_BUSRSP, (ulong *)&ap->status ) )
	{
		/* Already issued BUS RESET */
		HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - already reset bus \n");
		hfc_stra_trace(HFC_TRC_BUS_RESET ,0x30 ,ap , NULL, NULL, (ulong)cmnd, 0, 0) ;
		
		HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
		spin_unlock_irq(cmnd->device->host->host_lock);
#endif
		return(SUCCESS);
	}

	/* Start BUS RESET */
	HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - start reset bus \n");
	set_bit( HFC_WAIT_BUSRSP, (ulong *)&ap->status );		/* Set wait bus reset flag */
	
	if( ap->enable_tgtrst )
	{	/* Target Reset effective mode unsupport */
		
		for ( lp=0; lp<MAX_TARGET_PROBE; lp++ )
		{
			if ( (target = hfc_hash_target_info(ap, lp)) != NULL )
			{
				/* 
				 * (1) Cancel waiting status of SCSI initiation.
				 * (2) Cancel waiting status of SCSI response when LOGIN completes 
				 */
				/* Cancel waiting queue of SCSI initialization and Task Management */
				hfc_cancel_scsi_cmd(ap,target,0,NULL,SCS_WAIT_BUS_RESET, HFC_CSCSI_RESET,
					FALSE,TRUE, HFC_FLASH_TARGET );
				
				set_bit( HFC_WAIT_TARGET_RESET, (ulong *)&target->status );
				
				reset_pkt = hfc_get_new_hfcp(ap);
				if( reset_pkt == NULL )
				{
				/* No free space for hfc_pkt */
					HFC_DBGPRT(" hfcldd : hfc_device_reset - hfcp==NULL-error\n");
					
					set_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );		/* FCLNX-GPL-036 */
					hfc_watchdog_enter(ap, target, NULL, 0, HFC_RESTART_TMR, 0, TRUE);		/* FCLNX-GPL-036 */
					hfc_watchdog_enter(ap, target, NULL, 0, HFC_RESTART_TMR, 0, FALSE);
					goto WAIT_BUS_RST;
				}
				
				dummy_cmnd = hfc_get_new_cmnd(ap);
				if( dummy_cmnd == NULL)
				{
					/* No space for dummy scsi_cmnd */
					HFC_DBGPRT(" hfcldd : hfc_device_reset - dummy_cmnd==NULL-error\n");
					
					set_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );		/* FCLNX-GPL-036 */
					hfc_watchdog_enter(ap, target, NULL, 0, HFC_RESTART_TMR, 0, TRUE);		/* FCLNX-GPL-036 */
					hfc_watchdog_enter(ap, target, NULL, 0, HFC_RESTART_TMR, 0, FALSE);
					goto WAIT_BUS_RST;
				}
				
				memset(reset_pkt, 0, sizeof(struct hfc_pkt));
				memset(dummy_cmnd, 0, sizeof(struct scsi_cmnd));
				
				set_bit(CFLAG_VALID, (ulong *)&reset_pkt->cmd_flags);
				set_bit(CFLAG_BUS_RESET, (ulong *)&reset_pkt->cmd_flags);
				ap->pkt_no++;
				if (ap->pkt_no >= ap->pkt_num) ap->pkt_no = 0;
				ap->pkt_cnt++;
				
				reset_pkt->cmd_pkt   = dummy_cmnd;
				reset_pkt->target_id = target->target_id;
				reset_pkt->lun_id    = 0;
				reset_pkt->ap        = ap;
				reset_pkt->target    = target;
				reset_pkt->dev       = NULL;
				dummy_cmnd->host_scribble = (void *)reset_pkt;
				hfc_dummy_copy( cmnd, dummy_cmnd );
				ap->cmnd_no++;
				if (ap->cmnd_no >= ap->cmnd_num) ap->cmnd_no = 0;
				ap->cmnd_cnt++;
				
				hfc_enqueue_wx_que(target, reset_pkt);

				/* Start Target Reset */
				if( hfc_start( ap, target, reset_pkt) == TRUE )
				{
					clear_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );			/* FCLNX-GPL-036 */
					set_bit( HFC_WAIT_TARGET_RESET, (ulong *)&target->status );
					hfc_stra_trace(HFC_TRC_RESET, 0x73, ap, target, reset_pkt, (ulong)dummy_cmnd, 0, 0);
				}
WAIT_BUS_RST:
				bus_reset_imcomplete = TRUE;
			}
		}

		if (bus_reset_imcomplete != FALSE)
		{
			HFC_DBGPRT("hfc_eh_bus_reset : wait bus reset \n");
			
			do {
				find = FALSE;
				HFC_ADAPUNLOCK_IRQRESTORE(flags);
				spin_unlock_irq(cmnd->device->host->host_lock);
	
				set_current_state(TASK_UNINTERRUPTIBLE);
				schedule_timeout(HZ/10+1);					/* Wait 100ms */

				spin_lock_irq(cmnd->device->host->host_lock);
				HFC_ADAPLOCK_IRQSAVE(flags);

				for (lp = 0; lp<MAX_TARGET_PROBE; lp++)	{
					if ((tgt = hfc_hash_target_info(ap, lp)) != NULL) {
						if ( test_bit(HFC_WAIT_TARGET_RESET, (ulong *)&tgt->status) )
							find = TRUE;
					}
				}
			
			} while (find != FALSE);
		}
	}


	/* Issue LOGIN */
	for ( lp=0; lp<MAX_TARGET_PROBE; lp++ )
	{
		if ( (target = hfc_hash_target_info(ap, lp)) != NULL )
		{
			/* 
			 * (1) Cancel waiting status of SCSI initiation.
			 * (2) Cancel waiting status of SCSI response when LOGIN completes 
			 */
			/* Cancel waiting queue of SCSI initialization and Task Management */
			
			hfc_cancel_scsi_cmd(ap,target,0,NULL,SCS_WAIT_BUS_RESET, HFC_CSCSI_RESET,
				FALSE,TRUE, HFC_FLASH_TARGET );
			
			set_bit( HFC_WAIT_BUS_RESET, (ulong *)&target->status );
			
			if( HFC_TG_STATUS_TEST( HFC_WAIT_LOGIN, target ) || HFC_TG_STATUS_TEST( HFC_WAIT_CANCEL, target ) )	/* FCLNX-GPL-038 */
			{	/* Already LOGIN waiting status -> Set bus reset flag */
				bus_reset_imcomplete = TRUE;
				continue;
			}
			
			if( test_bit(HFC_SCN_WLINKUP,(ulong *)&target->status) ){
				set_bit(HFC_NEED_CANCEL, (ulong *)&target->status);
				clear_bit(HFC_NEED_LOGIN, (ulong *)&target->status);	/* FCLNX-GPL-038 */
			}
			
			if( hfc_issue_relogin(ap,target) )
			{
//				set_bit( HFC_NEED_LOGIN, (ulong *)&target->status );	/* FCLNX-GPL-038 */
				hfc_enque_login_req(ap, target);
			}
			
			bus_reset_imcomplete = TRUE;
		}
	}
	
	if (bus_reset_imcomplete != FALSE)
	{
		HFC_DBGPRT("hfc_eh_bus_reset : wait bus reset \n");
	
		do {
			find = FALSE;
			HFC_ADAPUNLOCK_IRQRESTORE(flags);
			spin_unlock_irq(cmnd->device->host->host_lock);

			set_current_state(TASK_UNINTERRUPTIBLE);
			schedule_timeout(HZ/10+1);					/* Wait 100ms */

			spin_lock_irq(cmnd->device->host->host_lock);
			HFC_ADAPLOCK_IRQSAVE(flags);

			for (lp = 0; lp<MAX_TARGET_PROBE; lp++)	{
				if ((tgt = hfc_hash_target_info(ap, lp)) != NULL) {
					if ( test_bit(HFC_WAIT_BUS_RESET, (ulong *)&tgt->status) )
						find = TRUE;
				}
			}
		
		}while (find != FALSE);
	}

	clear_bit(HFC_WAIT_BUSRSP, (ulong *)&ap->status);
	HFC_DBGPRT("hfcldd : hfc_eh_bus_reset - end\n");

	hfc_stra_trace(HFC_TRC_BUS_RESET ,0x10 ,ap ,NULL ,NULL, (ulong)cmnd, 0, 0 );
	HFC_ADAPUNLOCK_IRQRESTORE(flags);
#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,16)
	spin_unlock_irq(cmnd->device->host->host_lock);
#endif
	return(SUCCESS);

}   


/*
 * Function:    hfc_issue_task_mgm
 *
 * Purpose:     Issue Task Management command
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info
 *  rstp       - Pointer to rst_pkt
 *  lun        - Lun which issues Abort start
 *  mode       - HFC_ISSUE_ABORT 		: Issue ABORT
 *               HFC_ISSUE_TARGET_RESET : Issue TARGET RESET
 *
 * Returns:     
 *
 * Notes:       This function is called in the following timings.
 *              (1) Bus Reset is required 
 *              (2) Adapter is executing BUS RESET when target responds.
 *              (3) Adapter is executing BUS RESET when receive LOGIN response.
 *
 */
void hfc_issue_task_mgm(
	struct adap_info            *ap,
	struct target_info          *target,
	struct hfc_pkt              *hfcp,
	uint                        lun,
	uchar                       mode)
{
	struct scsi_cmnd            *cmnd, *dummy_cmnd;
	struct hfc_pkt              *abort_pkt,*reset_pkt;

	HFC_DBGPRT(" hfcldd : hfc_issue_task_mgm - start\n");
	
	hfc_stra_trace(
			HFC_TRC_ISSUE_TMGM, 0x00, ap, target, hfcp,
			 0, 0, 0);

	cmnd = hfcp->cmd_pkt;
	
	if ( !( test_bit( HFC_ONLINE, (ulong *)&ap->status ) ) )
	{
		return;
	}

	if ( test_bit( HFC_SCN_WLINKUP, (ulong *)&target->status ) )
	{
		return;
	}
	else if( test_bit( HFC_WAIT_LOGIN, (ulong *)&target->status ) )
	{
		return;
	}
	else if( test_bit( HFC_WAIT_CANCEL, (ulong *)&target->status ) )	/* FCLNX-GPL-038 */
	{
		return;
	}																	/* FCLNX-GPL-038 */
	else if ( test_bit( HFC_NEED_LOGIN, (ulong *)&target->status )
	       || (mode == HFC_ISSUE_LOGIN) )		/* FCLNX-0500 */
	{	/* Require LOGIN to the target */
		if( hfc_issue_relogin(ap, target) )
		{
			/* 
			 * If LOGIN initiation fails, enqueue next_login queue
			 * and terminate with error. 
			 */
			set_bit( HFC_NEED_LOGIN, (ulong *)&target->status );
			clear_bit(HFC_NEED_CANCEL, (ulong *)&target->status);	/* FCLNX-GPL-038 */
			hfc_enque_login_req(ap, target);
			hfc_stra_trace(
				HFC_TRC_ISSUE_TMGM, 0x12, ap, target, hfcp, (ulong)cmnd, 0, 0);
		}
	}
	else if (mode == HFC_ISSUE_TARGET_RESET)
	{	/* Issue Target Reset */
	
		if ( !ap->enable_tgtrst )
		{			
			/* Issue LOGIN */
			if ( hfc_issue_relogin(ap,target) )
			{
				set_bit( HFC_NEED_LOGIN, (ulong *)&target->status );
				clear_bit(HFC_NEED_CANCEL, (ulong *)&target->status);	/* FCLNX-GPL-038 */
				clear_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );			/* FCLNX-GPL-036 */
				hfc_enque_login_req(ap, target);
				
				hfc_stra_trace(HFC_TRC_ISSUE_TMGM, 0x77, ap, target, hfcp, (ulong)cmnd, 0, 0);
				return;
			}
			clear_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );				/* FCLNX-GPL-036 */
		
		}
		else
		{
			reset_pkt = hfc_get_new_hfcp(ap);
    		if( reset_pkt == NULL){
				/* No space for hfc_pkt */
				HFC_DBGPRT(" hfcldd : hfc_issue_task_mgm - hfcp==NULL-error\n");
				return;
			}
			
			dummy_cmnd = hfc_get_new_cmnd(ap);
    		if( dummy_cmnd == NULL){
				/* No dummy space for scsi_cmnd */
				HFC_DBGPRT(" hfcldd : hfc_issue_task_mgm - dummy_cmnd==NULL-error\n");
				return;
			}

			memset(reset_pkt, 0, sizeof(struct hfc_pkt));
			memset(dummy_cmnd, 0, sizeof(struct scsi_cmnd));

			set_bit(CFLAG_VALID, (ulong *)&reset_pkt->cmd_flags);
			set_bit(CFLAG_TARGET_RESET, (ulong *)&reset_pkt->cmd_flags);
			ap->pkt_no++;
			if (ap->pkt_no >= ap->pkt_num) ap->pkt_no = 0;
			ap->pkt_cnt++;

			reset_pkt->cmd_pkt   = dummy_cmnd;
			reset_pkt->target_id = target->target_id;
			reset_pkt->lun_id    = 0;
			reset_pkt->ap        = ap;
			reset_pkt->target    = target;
			reset_pkt->dev       = NULL;
			dummy_cmnd->host_scribble = (void *)reset_pkt;
			hfc_dummy_copy( cmnd, dummy_cmnd );
			ap->cmnd_no++;
			if (ap->cmnd_no >= ap->cmnd_num) ap->cmnd_no = 0;
			ap->cmnd_cnt++;
			
			hfc_enqueue_wx_que(target, reset_pkt);
			
			/* Initiate Target Reset */
			if (hfc_start( ap, target, reset_pkt) == TRUE)
			{
				clear_bit( HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );		/* FCLNX-GPL-036 */
				set_bit( HFC_WAIT_TARGET_RESET, (ulong *)&target->status );
		
				hfc_stra_trace(
					HFC_TRC_ISSUE_TMGM, 0x13, ap, target, reset_pkt, 
					(ulong)dummy_cmnd, 0, 0);
			}
		}
	}
	else if(mode == HFC_ISSUE_ABORT)
	{/* Issue Abort Task Set issue */

		/* cancel xob */
		hfc_cancel_xob(ap, target, lun, hfcp, HFC_FLASH_DEV);    /* FCWIN-XX */

		abort_pkt = hfc_get_new_hfcp(ap);
    	if( abort_pkt == NULL){
			/* No space for hfc_pkt */
			HFC_DBGPRT(" hfcldd : hfc_eh_abort - hfcp==NULL-error\n");
			ap->scsi_err_cnt++ ;
			return;
		}
	
		dummy_cmnd = hfc_get_new_cmnd(ap);
    	if( dummy_cmnd == NULL){
			/* No space for dummy scsi_cmnd */
			HFC_DBGPRT(" hfcldd : hfc_eh_abort - dummy_cmnd==NULL-error\n");
			ap->scsi_err_cnt++ ;
			return;
		}

		memset(abort_pkt, 0, sizeof(struct hfc_pkt));
		memset(dummy_cmnd, 0, sizeof(struct scsi_cmnd));

		set_bit(CFLAG_VALID, (ulong *)&abort_pkt->cmd_flags);
		set_bit(CFLAG_ABORT, (ulong *)&abort_pkt->cmd_flags);
		ap->pkt_no++;
		if (ap->pkt_no >= ap->pkt_num) ap->pkt_no = 0;
		ap->pkt_cnt++;

		abort_pkt->cmd_pkt   = dummy_cmnd;
		abort_pkt->target_id = CMND_TARGET(cmnd);
		abort_pkt->lun_id    = CMND_LUN(cmnd);
		abort_pkt->ap        = ap;
		abort_pkt->target    = target;
		abort_pkt->dev       = NULL;
		dummy_cmnd->host_scribble = (void *)abort_pkt;
		hfc_dummy_copy( cmnd, dummy_cmnd );
		ap->cmnd_no++;
		if (ap->cmnd_no >= ap->cmnd_num) ap->cmnd_no = 0;
		ap->cmnd_cnt++;

		hfc_enqueue_wx_que(target, abort_pkt);

		target->lustat[lun] &= ~HFC_NEED_ABORT;
		target->lustat[lun] |=  HFC_WAIT_ABORT;
		
		if (hfc_start(ap, target, abort_pkt) == TRUE)
		{	/* Target Reset initiation failed (resource busy) */
			target->lustat[lun] &= ~HFC_NEED_ABORT;
			target->lustat[lun] |=  HFC_WAIT_ABORT;
		}
	}
	else { /* mode == HFC_ISSUE_LOGIN */			/* FCLNX-0500 */
		if ( hfc_issue_relogin(ap,target) )
		{
			set_bit( HFC_NEED_LOGIN, (ulong *)&target->status );
			clear_bit(HFC_NEED_CANCEL, (ulong *)&target->status);	/* FCLNX-GPL-038 */
			hfc_enque_login_req(ap, target);
			
			hfc_stra_trace(HFC_TRC_ISSUE_TMGM, 0x77, ap, target, hfcp, (ulong)cmnd, 0, 0);
			return;
		}
	}												/* FCLNX-0500 */

	hfc_stra_trace(
			HFC_TRC_ISSUE_TMGM, 0x10, ap, target, hfcp, (ulong)cmnd, 0, 0);
	return;
}


/*
 * Function:    hfc_cancel_scsi_cmd
 *
 * Purpose:     Cancel Scsi_cmds which have already stored in xob, wait_end_que, wait_xob_que.
 *
 * Arguments:   
 *  ap            - Pointer to adap_info 
 *  target        - Pointer to target_info 
 *  lun           - lun number
 *  hfcp          - Pointer to hfc_pkt 
 *  adap_status   - Cause of cancellation
 *  we_que_cancel - Flag to specify cancellation of wait_end_que
 *  type          - Targets of Cancellation 
 *                    = HFC_FLASH_PACKET	  : ap,hfcp
 *                    = HFC_FLASH_DEV		  : ap,target,lun
 *                    = HFC_FLASH_TARGET	  : ap,target
 *
 * Returns:     
 *
 * context : user / kernel / interrupt
 *
 * Notes:			Lock adap_info before calling this function
 */
void hfc_cancel_scsi_cmd(struct adap_info	*ap,
						 struct target_info *target,
						 uint				lun,
						 struct hfc_pkt 	*hfcp,
						 uint				adap_status,
						 uchar				inh_altpath,
						 uchar				we_que_cancel,
						 uchar				tm_que_cancel,
						 uchar				type)
{
#if 0
	int lp,find;
	struct target_info *tgt;
#endif


	HFC_DBGPRT(" hfcldd : hfc_cancel_scsi_cmd - start\n");
	
	hfc_cancel_xob(ap,target,lun,hfcp,type) ;
	
	if( we_que_cancel == TRUE )
		hfc_cancel_weque(ap,target,lun,hfcp,adap_status,inh_altpath,type) ;
		
	if( tm_que_cancel == TRUE )
		hfc_cancel_tskmgm(ap, target, lun, hfcp, adap_status, type);
	
	hfc_cancel_wxque(ap,target,lun,hfcp,adap_status,inh_altpath,type) ;
	return;
}


#define SC_TARGET_RESET 0x20	 	/* SCSI Device Head wants the adapter 	*/
									/* driver to issue a Target Reset task	*/
									/* request to this device				*/
/*
 * Function:    hfc_cancel_xob
 *
 * Purpose:     Turn on the skip flag of xob with range from otp to inp - 1.
 *              to inp - 1.
 *              No specific response to caller in this function -- Commands 
 *              stored in xob are also stored in wait_end_queue, so cancellation 
 *              of wait_end_que will report the completion of process to caller 
 *              afterward.
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info
 *  lun        - lun number
 *  hfcp       - Pointer to hfc_pkt
 *  type       - Targets of Cancellation
 *                    = HFC_FLASH_PACKET  : ap,hfcp
 *                    = HFC_FLASH_DEV     : ap,target,lun
 *                    = HFC_FLASH_TARGET  : ap,target
 * Returns:     
 *  0          - No xob exists for cancellation.
 *  1          - Canceled one or more xobs.
 *
 * Notes:			Lock adap_info before calling this function
 */
int hfc_cancel_xob( struct adap_info	*ap,
					struct target_info	*target,
					uint				lun,
					struct hfc_pkt		*hfcp,
					uchar				type)
{
	uint	save_in_num, save_out_num, wk_save_in_num, wk_save_out_num ;
	uint	outp_num, inp_num ;
	int		cancel = 0;
	struct	xob 	*xob_ptr;

	HFC_DBGPRT(" hfcldd : hfc_cancel_xob - start\n");

#if _HFC_DEBUG_STRA_00
		hfc_stra_trace(HFC_TRC_CAN_XOB,0x00,
			ap,target,hfcp,NULL,type,lun,NULL) ;
#endif

	wk_save_in_num = ap->fw_init_p->xob_inp;
	wk_save_out_num = ap->fw_init_p->xob_outp;
	HFC_4B_TO_4L(save_in_num, wk_save_in_num);
	HFC_4B_TO_4L(save_out_num, wk_save_out_num);

	if( save_out_num == save_in_num )
	{
		/* Xob is empty */

		hfc_stra_trace(HFC_TRC_CAN_XOB,0x20,
			ap,target,hfcp,(unsigned long long)type,(unsigned long long)lun,(unsigned long long)NULL) ;

		return (0);
	}

	/* Caliculate sequential number of xob_inp and xob_outp */
	inp_num  = ((save_in_num & 0x00ff0000)>>16)*HFC_XOB_PER_PAGE ;
	inp_num  += (save_in_num & 0x0000ffff) ;
	outp_num = ((save_out_num & 0x00ff0000)>>16)*HFC_XOB_PER_PAGE ;
	outp_num += (save_out_num & 0x0000ffff) ;

	do {
		xob_ptr = &ap->xob[outp_num];

		if ( type == HFC_FLASH_DEV )	
		{
			/* Cancel each lun */
			if(( xob_ptr->drv_work.target_id ==				
				 ((uint)(target->target_id & 0xffffffff)) )
			 &&( xob_ptr->drv_work.lun_id  == lun ))
			{
				if(!(xob_ptr->bflag & SC_TARGET_RESET))
				{
					xob_ptr->skip |= HFC_XOB_SKIP ;
					cancel = 1;
				}
			}
		}
		else if( type == HFC_FLASH_TARGET )
		{
			/* Cancel target */
			if( xob_ptr->drv_work.target_id == 
				((uint)(target->target_id & 0xffffffff)))
			{
				if( !(xob_ptr->bflag & SC_TARGET_RESET) )
				{
					xob_ptr->skip |= HFC_XOB_SKIP ;
					cancel = 1;
				}
			}
		}
		else
		{
			break;
		}
		
		outp_num++ ;
		if( outp_num >= ap->xob_max )
			outp_num = 0 ;

	} while( outp_num != inp_num ) ;

#if _HFC_DEBUG_STRA_01			
		hfc_stra_trace(HFC_TRC_CAN_XOB,0x10,
			ap,target,hfcp,NULL,type,lun,NULL) ;
#endif

	return (cancel); 
}


/*
 * Function:    hfc_cancel_weque
 *
 * Purpose:     Dequeue hfc_pkt in we_que
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info
 *  lun        - lun number
 *  hfcp       - Pointer to hfc_pkt
 *  inh_altpath- 
 *  adap_status- Cause of cancellation
 *  ap         - Adap_info structure pointer
 *  type       - Range of cancellation
 *               type = HFC_FLASH_PACKET  : ap,hfcp
 *                    = HFC_FLASH_DEV     : ap,target,lun
 *                    = HFC_FLASH_TARGET  : ap,target
 * Notes: Lock adap_info before calling this function
 */
void hfc_cancel_weque( struct adap_info    *ap,
					   struct target_info  *target,
					   uint 			   lun,
					   struct hfc_pkt	   *hfcp,
					   uint 			   adap_status,
					   uchar 			   inh_altpath,
					   uchar			   type )
{
	int hash, result=0;
	struct hfc_pkt	*wk_hfcp, *next_hfcp;

#if _HFC_DEBUG_STRA_02	
		hfc_stra_trace(HFC_TRC_CAN_WE,0x00,
			ap,target,hfcp,NULL,type,lun,adap_status);
#endif

	HFC_DBGPRT(" hfcldd : hfc_cancel_weque - start\n");

	for (hash=0;hash<HASH_T_NUM;hash++)
	{
		wk_hfcp = target->we_que_top[hash];

		while ( wk_hfcp != NULL )
		{
			next_hfcp = wk_hfcp->cmd_forw;		/* Preserve next hfc_pkt */

			result = 0;
			
			if ( (type == HFC_FLASH_TARGET) 	/* Cancel each target	*/
			  || ((type == HFC_FLASH_DEV) 		/* Cancel each lun	*/
					&& (wk_hfcp->cmd_pkt != NULL) && (wk_hfcp->lun_id == lun) ))
			{
				/* Dequeue from we_que */
				if ((target->we_que_top[hash] == wk_hfcp)
				 && (target->we_que_end[hash] == wk_hfcp) )	/* Only one	*/
				{
					target->we_que_top[hash] = NULL;
					target->we_que_end[hash] = NULL;
				}
				else
				{
					if ( wk_hfcp == target->we_que_top[hash] )			/* queue top */
					{
						target->we_que_top[hash] = wk_hfcp->cmd_forw;
						target->we_que_top[hash]->cmd_prev = NULL;
					}
					else if ( wk_hfcp == target->we_que_end[hash])		/* queue end */
					{
						target->we_que_end[hash] = wk_hfcp->cmd_prev;
						target->we_que_end[hash]->cmd_forw = NULL;
					}
					else												/* Otherwise */
					{
						wk_hfcp->cmd_forw->cmd_prev = wk_hfcp->cmd_prev ;
						wk_hfcp->cmd_prev->cmd_forw = wk_hfcp->cmd_forw ;
					}
				}
				target->we_que_cnt-- ;

				if ( hfc_manage_info.hfcldd_mp_mod && hfc_manage_info.lg_target_info && wk_hfcp->dev)
					hfc_manage_info.npubp->hfc_queue_count(wk_hfcp, 1, 1);	/* we dequeue */

				wk_hfcp->cmd_forw = NULL;
				wk_hfcp->cmd_prev = NULL;

				if ( test_bit(CFLAG_ABORT,(ulong *)&wk_hfcp->cmd_flags)
				  || test_bit(CFLAG_LUN_RESET,(ulong *)&wk_hfcp->cmd_flags) )
				{
					/* Turn off HFC_WAIT_ABORT when cancel Abort Task Set request */
					target->lustat[wk_hfcp->lun_id] &= ~HFC_WAIT_ABORT;
				}
				else if ( test_bit(CFLAG_TARGET_RESET, (ulong *)&wk_hfcp->cmd_flags) ){
					/* Turn off HFC_WAIT_TARGET_RESET when cancel Target Reset request */
					clear_bit(HFC_WAIT_TARGET_RESET, (ulong *)&target->status );
				}
				else if ( test_bit(CFLAG_BUS_RESET, (ulong *)&wk_hfcp->cmd_flags) ){
					/* Turn off HFC_WAIT_TARGET_RESET when cancel Target Reset request */
					clear_bit(HFC_WAIT_TARGET_RESET, (ulong *)&target->status );
				}

				/* Store cancellation factor and scsi response */
				wk_hfcp->adap_status = adap_status ;

				/* Set reason code and initialize statistics */
				if( test_bit( CFLAG_TIMEOUT, (ulong *)&wk_hfcp->cmd_flags ) )
				{
					result = DID_TIME_OUT;
				}
				else if ( (target->lustat[wk_hfcp->lun_id] & HFC_WAIT_ABORT) 
					   || test_bit( HFC_WAIT_DEVRSP, (ulong *)&target->status )
					   || test_bit( HFC_WAIT_BUS_RESET, (ulong *)&target->status ) )
				{
					result = DID_RESET;
					set_bit(CFLAG_INH_ALTPATH, (ulong *)&wk_hfcp->cmd_flags);
				}
				else if (inh_altpath == HFC_CSCSI_RESET)
				{
					result = DID_RESET;
					set_bit(CFLAG_INH_ALTPATH, (ulong *)&wk_hfcp->cmd_flags);
				}
				else 
				{
					result = DID_ERROR;
				}
				
				wk_hfcp->cmd_pkt->result &= 0xff00ffff;
				wk_hfcp->cmd_pkt->result |= (result << 16);
				ap->scsi_err_cnt++ ;						/* Error termination count */
				hfc_iodone(ap, wk_hfcp->cmd_pkt, wk_hfcp);	/* Callback */
			}

			wk_hfcp = next_hfcp;				/* Move to the next hfc_pkt */
		}
	}

	return;
}


/*
 * Function:    hfc_cancel_wxque
 *
 * Purpose:     Dequeue hfc_pkt in wx_que
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info
 *  lun        - lun number
 *  hfcp       - Pointer to hfc_pkt
 *  inh_altpath- 
 *  adap_status- Cause of cancellation
 *  ap         - Adap_info structure pointer
 *  type       - Range of cancellation
 *               type = HFC_FLASH_PACKET  : ap,hfcp
 *                    = HFC_FLASH_DEV     : ap,target,lun
 *                    = HFC_FLASH_TARGET  : ap,target
 * Notes: Lock adap_info before calling this function
 */
void hfc_cancel_wxque( struct adap_info    *ap,
					   struct target_info  *target,
					   uint 			   lun,
					   struct hfc_pkt	   *hfcp,
					   uint 			   adap_status,
					   uchar 			   inh_altpath,
					   uchar			   type)
{
	struct hfc_pkt	   *wk_hfcp, *next_hfcp;
	int			   		result;


	HFC_DBGPRT(" hfcldd : hfc_cancel_wxque - start\n");

	hfc_stra_trace(HFC_TRC_CAN_WX,0x00,
			ap,target,hfcp,type,lun,adap_status);
			
	wk_hfcp = target->wx_que_top;
	
	while ( wk_hfcp != NULL )
	{
		next_hfcp = wk_hfcp->cmd_forw;	/* Preserve next hfc_pkt */
		result = 0;

		if ( (type == HFC_FLASH_TARGET) 		/* Cancel each target	*/
	  	|| ((type == HFC_FLASH_DEV) 			/* Cancel each lun	*/
				&& (wk_hfcp->cmd_pkt != NULL) && (wk_hfcp->lun_id == lun) ))
		{
			/* Dequeue from wx_que */
			hfc_deque_wx_que(target, wk_hfcp);

			/* Store cancellation factor and scsi response */
			wk_hfcp->adap_status = adap_status ;
			
			if ( test_bit(CFLAG_ABORT,(ulong *)&wk_hfcp->cmd_flags)
			  || test_bit(CFLAG_LUN_RESET,(ulong *)&wk_hfcp->cmd_flags) )
			{
				/* Turn off HFC_NEED_ABORT when cancel Abort Task Set request */
				target->lustat[wk_hfcp->lun_id] &= ~HFC_NEED_ABORT;
			}
			else if ( test_bit(CFLAG_TARGET_RESET, (ulong *)&wk_hfcp->cmd_flags) ){
				/* 
				 * Turn off _DEFER_TARGET_RESET and NEED_TARGET_RESET 
				 * when cancel Target Reset request 
				 */
				clear_bit(HFC_DEFER_TARGET_RESET, (ulong *)&target->target_reset);		/* FCLNX-GPL-036 */
				clear_bit(HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );		/* FCLNX-GPL-036 */
			}
			else if ( test_bit(CFLAG_BUS_RESET, (ulong *)&wk_hfcp->cmd_flags) ){
				/* 
				 * Turn off _DEFER_TARGET_RESET and NEED_TARGET_RESET 
				 * when cancel Target Reset request 
				 */
				clear_bit(HFC_DEFER_TARGET_RESET, (ulong *)&target->target_reset);		/* FCLNX-GPL-036 */
				clear_bit(HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );		/* FCLNX-GPL-036 */
			}
			
			/* Set reason code and initialize statistics */
			if( test_bit(CFLAG_TIMEOUT, (ulong *)&wk_hfcp->cmd_flags ) )
			{
				result = DID_TIME_OUT;
			}
			else if ( (target->lustat[wk_hfcp->lun_id] & HFC_WAIT_ABORT) 
				   || test_bit( HFC_WAIT_DEVRSP, (ulong *)&target->status )
				   || test_bit( HFC_WAIT_BUS_RESET, (ulong *)&target->status ) )
			{
				result = DID_RESET;
				set_bit(CFLAG_INH_ALTPATH, (ulong *)&wk_hfcp->cmd_flags);
			}
			else if (inh_altpath == HFC_CSCSI_RESET)
			{
				result = DID_RESET;
				set_bit(CFLAG_INH_ALTPATH, (ulong *)&wk_hfcp->cmd_flags);
			}
			else
			{
				result = DID_ERROR;
			}
			
			wk_hfcp->cmd_pkt->result &= 0xff00ffff;
			wk_hfcp->cmd_pkt->result |= (result << 16);
			ap->scsi_err_cnt++ ;							/* Error termination count  */
			hfc_iodone(ap, wk_hfcp->cmd_pkt, wk_hfcp);		/* Callback */
		}

		wk_hfcp = next_hfcp;					/* Move to the next hfc_pkt */
	}
	
	hfc_stra_trace(HFC_TRC_CAN_WX,0x10,
		ap,target,hfcp,(unsigned long long)type,(unsigned long long)lun,(unsigned long long)adap_status);
}

/*
 * Function:    hfc_refer_reset_buf
 *
 * Purpose:     
 *
 * Arguments:   
 *  target     - Pointer to target_info
 *  hfcp       - Pointer to hfc_pkt 
 *
 * Returns:     
 *
 * Notes:       
 */
struct hfc_pkt *hfc_refer_reset_buf(struct target_info *target, struct	hfc_pkt *hfcp)
{
	struct	hfc_pkt		*hfcp_wk=NULL ;
	int 	i;

	HFC_DBGPRT(" hfcldd : hfc_refer_reset_buf - start\n");

	for(i=0; i<HASH_T_NUM; i++)
	{
		hfcp_wk = target -> wx_que_top ;

		while( hfcp_wk != NULL )
		{
			if( hfcp_wk == hfcp )
			{
				/* The Target Reset request exists in wx_que */
				return(hfcp_wk);
			}
			hfcp_wk = (struct hfc_pkt *) hfcp_wk->cmd_forw ;
		}
	}
	return(hfcp_wk);
}


/*
 * Function:    hfc_cancel_tskmgm
 *
 * Purpose:     Cancel we_que
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info
 *  lun        - lun number
 *  hfcp       - Pointer to hfc_pkt
 *  adap_status- Cause of cancellation
 *  ap         - Adap_info structure pointer
 *  type       - Range of cancellation
 *               type = HFC_FLASH_PACKET  : ap,hfcp
 *                    = HFC_FLASH_DEV     : ap,target,lun
 *                    = HFC_FLASH_TARGET  : ap,target
 * Returns:     
 *
 * Notes:       
 */
void hfc_cancel_tskmgm(
	struct adap_info            *ap,
	struct target_info          *target,
	uchar                       lun,
	struct hfc_pkt              *hfcp,
	uint                        adap_status,
	uint                        type)
{
	uint                        lp;

	if (type == HFC_FLASH_TARGET)
	{
		if (test_bit(HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset) )		/* FCLNX-GPL-036 */
		{
			clear_bit(HFC_NEED_TARGET_RESET, (ulong *)&target->target_reset );		/* FCLNX-GPL-036 */
			clear_bit(HFC_DEFER_TARGET_RESET, (ulong *)&target->target_reset );		/* FCLNX-GPL-036 */
		}
	}

	for (lp=0;lp<MAX_DEV_CNT;lp++)
	{
		if ((type == HFC_FLASH_TARGET)
		 || ((type == HFC_FLASH_DEV) && (lp == lun)))
		{
			if (target->lustat[lp] & HFC_NEED_ABORT)
			{
				target->lustat[lp] &= ~(HFC_NEED_ABORT | HFC_DEFER_ABORT);
			}
		}
	}
}


/*
 * Function:    hfc_deque_wx_que
 *
 * Purpose:     
 *
 * Arguments:   
 *  target     - Pointer to target_info
 *  hfcp       - Pointer to hfc_pkt
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_deque_wx_que(struct target_info *target, struct hfc_pkt *hfcp)
{
	struct hfc_pkt *hfcp_wk ;

	/* Two or more packets exist in queue-*/
	if( hfcp == target->wx_que_top )
	{
		if (hfcp == target->wx_que_end) {
			target->wx_que_top = NULL ;
			target->wx_que_end = NULL ;
		}
		else {
			/* Dequeue from the top */
			target->wx_que_top = (struct hfc_pkt *)hfcp->cmd_forw ;
			target->wx_que_top->cmd_prev = NULL ;
		}
	}
	else if( hfcp == target->wx_que_end )
	{
		/* Dequeue from the end */
		target->wx_que_end = (struct hfc_pkt *)hfcp->cmd_prev ;
		target->wx_que_end->cmd_forw = NULL ;
	}
	else
	{
		/* Otherwise */
		hfcp_wk = (struct hfc_pkt *)hfcp->cmd_prev ;
		hfcp_wk->cmd_forw = hfcp->cmd_forw ;
		hfcp_wk = (struct hfc_pkt *)hfcp->cmd_forw ;
		hfcp_wk->cmd_prev = hfcp->cmd_prev ;
	}
	target->wx_que_cnt--;
	
	if ( hfc_manage_info.hfcldd_mp_mod && hfc_manage_info.lg_target_info && hfcp->dev)
		hfc_manage_info.npubp->hfc_queue_count(hfcp, 0, 1);	/* wx dequeue */

	hfcp->cmd_forw = NULL ;
	hfcp->cmd_prev = NULL ;
	return ;
}


/*
 * Function:    hfc_enqueue_wx_que
 *
 * Purpose:     
 *
 * Arguments:   
 *  target     - Pointer to target_info
 *  hfcp       - Pointer to hfc_pkt
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_enqueue_wx_que(struct target_info *target, struct hfc_pkt *hfcp)
{
	HFC_DBGPRT(" hfcldd : hfc_enqueue_wx - start\n");

	if( target->wx_que_top == NULL ) {
		/* Add packet to empty queue */	
		target->wx_que_top = hfcp ;	
		target->wx_que_end = hfcp ;
		hfcp->cmd_forw = NULL;
		hfcp->cmd_prev = NULL;
	}
	else {
		/* Enqueue packet to the end of the cue */
		target->wx_que_end->cmd_forw = hfcp;
		hfcp->cmd_prev = target->wx_que_end ;
		target->wx_que_end = hfcp ;
	}
	target->wx_que_cnt++ ;
	
	if ( hfc_manage_info.hfcldd_mp_mod && hfc_manage_info.lg_target_info && hfcp->dev)
		hfc_manage_info.npubp->hfc_queue_count(hfcp, 0, 0);	/* wx enqueue */

}


/*
 * Function:    hfc_resource_chk
 *
 * Purpose:     Check remaining resource of xob, scmd_buf, and iov_map.
 *              Completing this function means ap->iov_no and hfcp->iov_cnt
 *              is set and iov_map is renewed.
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info
 *  hfcp       - Pointer to hfc_pkt
 *  fw_xob_outp- 
 *
 * Returns:     
 *  0                  - Success
 *  HFC_XOB_EMPTY(1)   - Success (Xob is empty)
 *  HFC_XOB_FULL(4)    - Xob is full
 *  HFC_SCMD_FULL(5)   - Scmd_buf is full
 *  HFC_IOVMAP_FULL(6) - Bus address area is full for DMA mapping
 *  HFC_PAGE_OVER(-1)  - The number of Pages is larger than iov_map_cnt
 *  
 *
 * Notes: This routine is called from the process level and the interruption level.

 */
int hfc_resource_chk(struct adap_info *ap, 
					 struct target_info *target,
					 struct hfc_pkt *hfcp,
					 uint   fw_xob_outp)
{
	struct scsi_cmnd	*cmnd ;
	uint				xob_out_num ;
	uint				page_cnt = 0 ;
	uint				bit_pos = 0 ;
	uint				start_pos_word = 0 ;
	uint				start_pos_in_word = 0 ;
	struct free_iov_map	free_iov ;
	uchar				find ;
	uint				seg_cnt,  i;
	uint32_t			data_size, transfer_size;
	dma_addr_t			b_dma_a;
	uint64_t			dma_a;


#if _HFC_DEBUG_STRA_03
	hfc_stra_trace(HFC_TRC_RES_CHK,0x00,
		ap,target,dev,(unsigned long long)dev->wx_que_top,
		NULL,NULL) ;
#endif
	/* Caliculate sequential number of xob_outp from page and entry number */
	xob_out_num = ((fw_xob_outp & 0x00ff0000)>>16) * HFC_XOB_PER_PAGE ;
	xob_out_num += (fw_xob_outp & 0x0000ffff) ;
	
	cmnd = hfcp->cmd_pkt ;
	
	if( cmnd == NULL){
		HFC_DBGPRT(" hfcldd%d : hfc_resource_chk - cmnd == NULL \n", ap->dev_minor);
		return( HFC_XOB_FULL ) ;
	}

	/* Is xob full? */
	if( (ap->xob_no == (ap->xob_max-1)) &&
		(xob_out_num == 0) ) 
	{
		HFC_DBGPRT(" hfcldd : hfc_resource_chk - (ap->xob_no == (ap->xob_max-1)) &&	(xob_out_num == 0)\n");

		hfc_stra_trace(HFC_TRC_RES_CHK,0x11, ap,target,hfcp, (ulong)cmnd, 0, 0);
		/* Inp is the last entry of xob and outp is the top of xob */
		return( HFC_XOB_FULL ) ;
	}
	if( (ap->xob_no + 1) == xob_out_num )
	{
		HFC_DBGPRT(" hfcldd : hfc_resource_chk - (ap->xob_no + 1) == xob_out_num \n");
		
		hfc_stra_trace(HFC_TRC_RES_CHK,0x12, ap,target,hfcp, (ulong)cmnd, 0, 0);

		/* outp = inp + 1*/
		return( HFC_XOB_FULL ) ;
	}

	/* Caliculate necessary number of pages */
	page_cnt = 0 ;
	if(cmnd->use_sg != 0)
	{
		hfcp->seg_cnt = pci_map_sg(ap->pci_cfginf, cmnd->request_buffer, cmnd->use_sg, 
				scsi_to_pci_dma_dir(cmnd->sc_data_direction));

		if (!hfcp->seg_cnt) {
			HFC_DBGPRT(" hfcldd : hfc_resource_chk - pci_map_sg() == 0\n");
			return( HFC_XOB_FULL ) ;
		}
	}
	else{
		hfcp->seg_cnt = 0;
	}
	seg_cnt = hfcp->seg_cnt;

	if(seg_cnt == 0){
		data_size = (int)cmnd->request_bufflen;
		if(data_size == 0)
		{
			page_cnt = 0;
		}
		else 
		{
			page_cnt = 1;
		}
	}
	else {
		struct	scatterlist *cur_seg;
		struct	scatterlist *scatter_list;

		scatter_list = (struct scatterlist *)cmnd->request_buffer;
		cur_seg = scatter_list;
		transfer_size = 0;

		for(i=0; i<seg_cnt; i++) {
			uint32_t	b_length;

			/* Allocate additional packets */
			b_length = sg_dma_len(cur_seg);
			transfer_size += b_length;
			cur_seg++;
			page_cnt++;
		}
		
		
		data_size = transfer_size;
	}
	hfcp->data_size = data_size;

	if( page_cnt > ap->iov_map_cnt )
	{
		HFC_ERRPRT(" hfcldd : hfc_resource_chk - page_cnt > ap->iov_map_cnt\n");

		b_dma_a = sg_dma_address((struct scatterlist *)cmnd->request_buffer);
		dma_a = (uint64_t)b_dma_a;
		HFC_BZERO(logdata,16) ;
		HFC_MEMCPY(logdata,(uchar*)&dma_a, 8) ;
		HFC_MEMCPY(&logdata[8],(uchar*)&(hfcp->data_size),4) ;
		HFC_MEMCPY(&logdata[12],(uchar*)&page_cnt,4) ;
		hfc_errlog(ap,target,hfcp,HFC_ERRLOG_TYPE_NONE,
								ERRID_HFCP_ERR9,0x05,logdata,16) ;
		return( HFC_PAGE_OVER ) ;
	}
	
	hfcp->iov_cnt = 0 ;
	hfcp->iov_no = 0 ;
	if( ( page_cnt > 0 ) && ( !( HFC_HFCP_CFLAG_TEST(CFLAG_SEGVALID, hfcp) ) ) )
	{
		/* Search necessary consecutive area from iov_map */
		start_pos_in_word = 0 ;		/* Start bit for search */
		start_pos_word = 0 ;		/* Start word for search */
									/* The top address of iov_map		*/
		bit_pos = 0 ;
		find = FALSE ;
		while( (bit_pos < ap->iov_map_cnt) && (find == FALSE) )
		{
			/* Caliculate bit position and length of consecutive area */
			hfc_get_free_iov(ap,start_pos_word,
								start_pos_in_word,page_cnt,&free_iov) ;

			/* No enough space in iov_map */
			if( free_iov.free_cnt == 0 )
			{
				hfc_stra_trace(HFC_TRC_RES_CHK,0x14, ap,target,hfcp, (ulong)cmnd, 0, 0);
				return( HFC_IOVMAP_FULL ) ;
			}
			if( free_iov.free_cnt >= page_cnt )
			{
				ap->iov_no = free_iov.free_pos ;
				hfcp->iov_no = ap->iov_no;
				hfcp->iov_cnt = page_cnt ;
				find = TRUE ;
				break ;
			}
			else
			{
				start_pos_word = bit_pos / 32 ;
				start_pos_in_word = bit_pos % 32 ;
			}
			bit_pos = free_iov.free_cnt + free_iov.free_pos ;
		}
		if( find == FALSE )
		{
			hfc_stra_trace(HFC_TRC_RES_CHK,0x14, ap,target,hfcp, (ulong)cmnd, 0, 0);
			return( HFC_IOVMAP_FULL ) ;
		}
		
		if( ( hfcp->iov_cnt+hfcp->iov_no ) > ap->iov_map_cnt )
		{
			HFC_ERRPRT(" hfcldd : hfc_resource_chk - ( hfcp->iov_cnt+hfcp->iov_no ) > ap->iov_map_cnt \n");

			hfc_stra_trace(HFC_TRC_RES_CHK,0x14,
				ap,target,hfcp, (ulong)cmnd, 0, 0);
			return( HFC_IOVMAP_FULL ) ;
		}
		hfc_iov_update(ap,free_iov.free_pos,page_cnt,0) ;
    }
	if( ap->xob_no == xob_out_num )
	{
#if _HFC_DEBUG_STRA_04
		hfc_stra_trace(HFC_TRC_RES_CHK,0x15,
			dev->ap,target,dev,(unsigned long long)dev->wx_que_top,
			NULL,NULL) ;
#endif
		return( HFC_XOB_EMPTY ) ;
	
	}
#if _HFC_DEBUG_STRA_05
	hfc_stra_trace(HFC_TRC_RES_CHK,0x10,
		ap,target,(unsigned long long)target->wx_que_top,
		NULL,NULL) ;
#endif	

	return(0) ;
}


/*
 * Function:    hfc_get_free_iov
 *
 * Purpose:     Find first available consecutive bits from the position of
 *              st_word and st_bit in iov_map. 
 *              Iov_map is full when free_iov_map.free_cnt is zero.
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  st_word    - Start position of word search
 *  st_bit     - Start position of bit search
 *  req_bit_cnt - 
 *  fmap        -
 *
 * Returns:     
 *  free_iov_map.free_cnt - Number of available consecutive bits
 *  free_iov_map.free_pos - Bit start position of free_cnt in iov_map
 *
 * Notes:		Lock adap_info before calling this function
 */
void hfc_get_free_iov(struct adap_info *ap ,
									 uint st_word,
									 uint st_bit,
									 uint req_bit_cnt,
									 struct	free_iov_map *fmap)
{
	uint	*iov ;					/* iov_map				*/
	uint	word_pos = 0 ;			/* word position of iov_map  */
	uint    bit_pos = 0 ;			/* bit position of iov_map  */
	uint	chk_bit_cnt = 0 ;		/* number of checked bits */
	uint	shift = 0x80000000 ;    /* check bit		*/
	uint	lp ;
	uchar	find = FALSE ;			/* Empty aera detection flag */
	struct	free_iov_map	free_map ;
	iov = ap->iov_map ;			
	word_pos = st_word ;			
	bit_pos = st_word*32 + st_bit ;	
	free_map.free_pos = 0 ;			
	free_map.free_cnt = 0 ;         
	chk_bit_cnt = 0 ;				


	if( st_bit != 0 )
	{
		for(lp=st_bit ; lp<32 ; lp++)
		{
			if( (shift >> lp) & iov[word_pos] )
			{
				/* Detect "1" (unused) */
				if( find == FALSE )
				{
					/* Detect unused area for the first time? */
					find = TRUE ;
					/* Set bit position to free_map */
					free_map.free_pos = bit_pos ;
				}
				
				bit_pos++ ;
				/* Set the number of free bits to free_map */
				free_map.free_cnt++ ;
			}
			else
			{
				/* Detect "0" (already used) */
				if( find == TRUE )
				{	
					/* Return current bits stored in free_map */
					*fmap = free_map;
					return;
				}
				else
					/* increment bit position */
					bit_pos++ ;
			}
			if( bit_pos >= ap->iov_map_cnt )
			{
				/* Bit position exceeded the maximum bit position */
				*fmap = free_map;
				return;
			}
			if( free_map.free_cnt > req_bit_cnt ) {
				*fmap = free_map;
				return;
			}
		}

		word_pos++ ; /* Move to the next word */
	}

	while( bit_pos < ap->iov_map_cnt )
	{
		if( free_map.free_cnt > req_bit_cnt ) {
			*fmap = free_map;
			return;
		}
		
		if( iov[word_pos] == 0 )
		{
			/* This word is full */
			if( find == TRUE )
			{
				*fmap = free_map;
				return;
			}
			else {
				bit_pos += 32 ;
				word_pos++ ;
				continue ;
			}
		}
		if( iov[word_pos] == 0xffffffff )
		{
			/*This word is empty */
			if( find == TRUE ) {
				free_map.free_cnt += 32 ;
				bit_pos += 32 ;
				word_pos++ ;
				continue ;
			}
			else {
				/* Detect "1" for the first time. */
				find = TRUE ;
				free_map.free_pos = bit_pos ;
				free_map.free_cnt += 32 ;
				bit_pos += 32 ;
				word_pos++ ;
				continue ;
			}
		}
		/* Iov word_pos is neither all zeros nor all 1. --*/
		for(lp=0 ; lp<32 ; lp++)
		{
			if( (shift >> lp) & iov[word_pos] )
			{
				if( find == FALSE )
				{
					find = TRUE ;
					free_map.free_pos = bit_pos ;
				}
				free_map.free_cnt++ ;
				bit_pos++ ;
			}
			else
			{
				if( find == TRUE )
				{
					*fmap = free_map;
					return;
				}
				else
					bit_pos++ ;
			}
			
			if( bit_pos >= ap->iov_map_cnt )
			{
				*fmap = free_map;
				return;
			}

			if( free_map.free_cnt > req_bit_cnt ) {
				*fmap = free_map;
				return;
			}

		}
		word_pos++ ;
	}

	*fmap = free_map;
	return;
}


/*
 * Function:    hfc_iov_update
 *
 * Purpose:     Update bits of ap->iov_map with specified type starting from 'pos'
 *              bit to 'pos + cnt' bit.
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  pos        - Update start bit in iov_map
 *  cnt        - Number of update counts in iov_map
 *  type       - 0 : This area is used 1: This area is free
 *
 * Returns:     
 *
 * Notes:		Lock adap_info before calling this function
 */
void hfc_iov_update(struct adap_info *ap ,
					uint pos ,
					uint cnt ,
					uchar type)
{
	uint	*iov ;					/* iov_map				*/
	uint	word_pos = 0 ;			/* Word position of iov_map  */
	uint    bit_pos_in_word ;		/* Bit position in word   */
	uint	shift = 0x80000000 ;    /* check bit		*/
	uint	bit_cnt = 0 ;
	uint	bit_pos = 0 ;
#if _HFC_DEBUG_STRA_06
	uchar	trc_iov[128] ;	
#endif
#if _HFC_DEBUG_STRA_07
	hfc_stra_trace(HFC_TRC_IOVUP,0x00,
		ap,NULL,NULL,(unsigned long long)type,
		(unsigned long long)pos,(unsigned long long)cnt ) ;
#endif
	word_pos = pos/32 ;
	bit_pos_in_word = pos%32 ;
	iov = ap->iov_map ;
	bit_cnt = cnt ;
	bit_pos = pos ;

#if _HFC_DEBUG_STRA_06	
	memset(trc_iov,0,128);
	memcpy(&trc_iov[16],(char *)iov,32);
#endif

	while( bit_cnt != 0 )
	{
		if( bit_pos_in_word != 0 )
		{
			if( type == 0 )
				iov[word_pos] &= ~(shift >> bit_pos_in_word) ;
			else
				iov[word_pos] |= (shift >> bit_pos_in_word) ;
			
			bit_pos++ ;
			bit_cnt-- ;
		}
		else
		{
			if( bit_cnt > 32 )
			{
				if( type == 0 )
					iov[word_pos] = 0 ;
				else
					iov[word_pos] = 0xffffffff ;
				bit_pos+=32 ;
				bit_cnt-=32 ;
			}
			else
			{
				if( type == 0 )
					iov[word_pos] &= ~(shift >> bit_pos_in_word) ;
				else
					iov[word_pos] |= (shift >> bit_pos_in_word) ;
				bit_pos++ ;
				bit_cnt-- ;
			}
		}
		if( bit_pos < ap->iov_map_cnt )
		{
			word_pos = bit_pos/32 ;
			bit_pos_in_word = bit_pos%32 ;
		}
		else
		{
#if _HFC_DEBUG_STRA_08
			hfc_stra_trace(HFC_TRC_IOVUP,0x11,
				ap,NULL,NULL,(unsigned long long)type,
				(unsigned long long)pos,(unsigned long long)cnt ) ;
#endif
#if _HFC_DEBUG_STRA_06	
			memcpy(&trc_iov[48],(char *)iov,32);
			hfc_trace(ap,0xFF,&trc_iov[1],0);
#endif
			return ;
		}
	}
	
#if _HFC_DEBUG_STRA_09
	hfc_stra_trace(HFC_TRC_IOVUP,0x10,
			ap,NULL,NULL,(unsigned long long)type,
			(unsigned long long)pos,(unsigned long long)cnt ) ;
#endif
#if _HFC_DEBUG_STRA_06	
	memcpy(&trc_iov[48],(char *)iov,32);
	hfc_trace(ap,0xFF,&trc_iov[1],0);
#endif
	return ;
}


/*
 * Function:    hfc_dma_map
 *
 * Purpose:     Setup DMA cookie from seg_info
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  hfcp       - Pointer to hfc_pkt
 *
 * Returns:     
 *  DMA_SUCC(0) - success
 *  DMA_NOACC   - Unable to access
 *
 * context:   user / interrupt
 *
 * Notes:		Lock adap_info before calling this function
 *              This function set xob->seg_1st, xob->seg_cnt and xob->seg_info_xob
 *              in addition to seg_info of hfc_pkt.
 */
int hfc_dma_map( struct adap_info *ap, struct hfc_pkt *hfcp )
{
	uint				seg_info_no ;				/* seg_info area offset number */
	uint				seg_no ;					/* seg_infonumber in xob 	*/
	uint64_t			seg_info_baddr = 0; 		/* seg_info badr in xob */
	uint				lp, page_cnt ,xob_no,cn=0;
	struct seg_info 	*seg_info_ptr=NULL;
	struct scsi_cmnd	*cmnd;
	dma_addr_t	b_dma_a;
	uint32_t	b_length;
	uint		xob_segno;
	uint64_t	dma_add;
	struct scatterlist *cur_seg;
	struct scatterlist *scatter_list;
	dma_addr_t			req_dma;
	uint32_t				req_len;	
	struct page			*page;
	unsigned long			offset;
	uint		copy_seg_num;

	if( hfcp->iov_cnt ) /* Iov has already allocated  for this hfcp --> use seginfo */
	{	/* Iov has already allocated  for this hfcp --> use seginfo */
	
		/* Add 'page number - 1' for the seg_info_no after the page of 2 */
		seg_info_no = hfcp->iov_no + (hfcp->iov_no / (HFC_SEG_PER_PAGE-1)) ;

		/* Caliculate page number of this seg_info */
		lp = seg_info_no / HFC_SEG_PER_PAGE ;
		if( lp == 0 )
		{
			/* Setup the start address of seg_info if pages number is zero */
			seg_info_baddr = ap->seg_phys_addr;
		}
		else
		{
			/* 
			 * Page address is set in the last entry of previous page 
			 * if page number is not zero.
			 */ 
			lp = (lp * HFC_SEG_PER_PAGE) - 1 ;
			if( !(ap->seg_info[lp].seg_len & HFC_SEG_LEN_F))
			{

				/* Failed if HFC_SEG_LEN_F is zero 0. */
				HFC_MEMCPY(logdata,(uchar*)&(hfcp->data_size),4) ; 
				HFC_MEMCPY(&logdata[8],(uchar*)&page_cnt,4) ;
				HFC_MEMCPY(&logdata[12],(uchar*)&seg_info_no,4) ;
				hfc_errlog(ap,NULL,hfcp,HFC_ERRLOG_TYPE_NONE,
									ERRID_HFCP_ERR9,0x08,logdata,16) ;

				hfc_iov_update(ap, hfcp->iov_no, hfcp->iov_cnt, 1) ;

				hfc_stra_trace(HFC_TRC_DMA_MAP,0x20,
					ap,NULL,hfcp, (unsigned long long)NULL, (unsigned long long)NULL, (unsigned long long)NULL);

				return( FAILED ) ;
			}

			HFC_8B_TO_8L(seg_info_baddr, ap->seg_info[lp].seg_addr);
		}

		/* Add page offset byte to seg_info bus address */
		seg_info_baddr += ((seg_info_no % HFC_SEG_PER_PAGE)*
									sizeof(struct seg_info)) ;
	}

	/* Set seg_info */
	xob_no = ap->xob_no;
	hfcp->cmd_xob = xob_no;
	cmnd = hfcp->cmd_pkt;
	
	scatter_list = (struct scatterlist *)cmnd->request_buffer;
	

	if ( hfcp->data_size > 0 )	/* Transfer data exists? */
	{

		cur_seg = scatter_list;
		if (hfcp->seg_cnt == 0)
		{
			cn = 0;
			seg_no = seg_info_no; 					/* seg_info offset		*/
			do
			{
				seg_info_ptr = &ap->seg_info[seg_no];
				if (!(seg_info_ptr->seg_len & HFC_SEG_LEN_F))
				{

					page = virt_to_page(cmnd->request_buffer);
					offset = ((unsigned long)
							 cmnd->request_buffer 
							 & ~PAGE_MASK);

					req_dma = pci_map_page(ap->pci_cfginf,
						page,
						offset,
						cmnd->request_bufflen,
						scsi_to_pci_dma_dir(
						cmnd->sc_data_direction));
					req_len = cmnd->request_bufflen;
			
					dma_add = (uint64_t)req_dma;
				
					hfcp->dma_handle = req_dma;
			
					HFC_8L_TO_8B(seg_info_ptr->seg_addr, dma_add);
					HFC_4L_TO_4B(seg_info_ptr->seg_len, req_len);
			
					xob_segno = (uint)((xob_no << 24) & 0xff000000) | cn ;
					HFC_4L_TO_4B(seg_info_ptr->xob_segno, xob_segno);
			
					cn++;
				}
				seg_no++;
			}
			while (cn < hfcp->seg_cnt);
			
			/* Turn on L bit of final seg_info */
				seg_info_ptr->seg_len |= HFC_SEG_LEN_L ;
		
			/* Copy seg_info to xob. */
			HFC_MEMCPY(ap->xob[xob_no].seg_info_xob,
				&ap->seg_info[seg_info_no],
				(sizeof(struct seg_info)));
		}
		else
		{

			/* Copy XOB_SEGNUM to XOB. */
			cn = 0; 								/* DMA cookie#			*/
			seg_no = seg_info_no; 					/* seg_info offset		*/

			if(hfcp->seg_cnt > 0)
			{

				do
				{
					seg_info_ptr = &ap->seg_info[seg_no];
					if (!(seg_info_ptr->seg_len & HFC_SEG_LEN_F))
					{
						b_dma_a = sg_dma_address(cur_seg);
						b_length = sg_dma_len(cur_seg);
						
						if(cn == 0 )
						{
							hfcp->dma_handle = b_dma_a;
						}
				
						dma_add = (uint64_t)b_dma_a;
						HFC_8L_TO_8B(seg_info_ptr->seg_addr, dma_add);
						HFC_4L_TO_4B(seg_info_ptr->seg_len, b_length);
						xob_segno = (uint)((xob_no << 24) & 0xff000000) | cn ; 
						HFC_4L_TO_4B(seg_info_ptr->xob_segno, xob_segno);
						cur_seg++;									
						cn++;
						
				
					}
					seg_no++;
				}
				while (cn < hfcp->seg_cnt);		
				
				/* Turn on L bit of final seg_info */
				seg_info_ptr->seg_len |= HFC_SEG_LEN_L ;
				
				/* Copy seg_info to xob. */
				if( hfcp->seg_cnt <= XOB_SEGNUM )
				{
					copy_seg_num = hfcp->seg_cnt;
				}
				else
				{
					copy_seg_num = XOB_SEGNUM;
				}
				HFC_MEMCPY(ap->xob[xob_no].seg_info_xob,
						&ap->seg_info[seg_info_no],
						(sizeof(struct seg_info)* copy_seg_num));

			}
		}

		set_bit(CFLAG_SEGVALID, (ulong *)&hfcp->cmd_flags);

		/* Set all allocated iov_cnt in seg_info.	*/
		/* F bit should be zero in the final seg_info.	*/
	}

	HFC_8L_TO_8B(ap->xob[xob_no].seg_1st, seg_info_baddr);
	HFC_4L_TO_4B(ap->xob[xob_no].seg_cnt, cn);	/* No count for F=1 case */
	

#if _HFC_DEBUG_STRA_10
	hfc_dump_hex("hfc_dma_map() - xob     "
								,&ap->xob[xob_no],sizeof(struct xob));
	cmn_err(CE_CONT,"hfcp->iov_no = %x,hfcp->iov_cnt = %x",
									hfcp->iov_no,hfcp->iov_cnt);
#endif	

	return( SUCCESS ) ;
}


/*
 * Function:    hfc_make_cmdiu
 *
 * Purpose:     Set FCP-CMD-IU payload to the area pointed by hfc_pkt->cmd_xob
 *              Generate setting data from scsi_pkt and hfcpkt.
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  hfcp       - Pointer to hfc_pkt 
 *
 * Returns:     
 *
 * context:     user / kernel / interrupt
 *
 * Notes:		Lock adap_info before calling this function
 */
void hfc_make_cmdiu( struct adap_info *ap, struct hfc_pkt *hfcp )
{
	struct fcp_cmd_iu  fcp_cmd;
	struct scsi_cmnd *cmnd = hfcp->cmd_pkt;
	
	/* Caliculate pointer to FCP-CMD-IU area of xob and clear the area */
	HFC_BZERO( &fcp_cmd, sizeof(struct fcp_cmd_iu) );
	
	/* FCP-LUN Byte0,1 */
	fcp_cmd.fcp_lun.lun = (uchar)hfcp->lun_id;

	/* FCP-CNTL Byte1 */
	if( !test_bit(CFLAG_ABORT, (ulong *)&hfcp->cmd_flags)
	 && !test_bit(CFLAG_LUN_RESET, (ulong *)&hfcp->cmd_flags) 
	 && !test_bit(CFLAG_TARGET_RESET, (ulong *)&hfcp->cmd_flags) 
	 && !test_bit(CFLAG_BUS_RESET, (ulong *)&hfcp->cmd_flags) ) 
	{
  		if (cmnd->device->tagged_supported) {
    		switch (cmnd->tag) {
    		case HEAD_OF_QUEUE_TAG:
      			fcp_cmd.fcp_cntl.qtype = 1;			/* Head-of-Q			*/
      			break;
    		case ORDERED_QUEUE_TAG:
      			fcp_cmd.fcp_cntl.qtype = 2;			/* Ordered-Q			*/
      			break;
    		default:
      			fcp_cmd.fcp_cntl.qtype = 0;			/* Simple-Q 			*/
    			break;
    		}
  		}
  		else{
    		fcp_cmd.fcp_cntl.qtype = 5;				/* Untagged-Q			*/
    	}
  	}
  	else{
    	fcp_cmd.fcp_cntl.qtype = 5;				/* Untagged-Q			*/
    }


	/* FCP-CNTL Byte2 */
	if(test_bit(CFLAG_ABORT, (ulong *)&hfcp->cmd_flags))
	{
		/* Abort Task Set */
		fcp_cmd.fcp_cntl.task_mgm |= HFC_ABORT_TASK;
	}
	else if(test_bit(CFLAG_LUN_RESET, (ulong *)&hfcp->cmd_flags))
	{
		/* LUN Reset */
		fcp_cmd.fcp_cntl.task_mgm |= HFC_LUN_RST;
	}
	else if(test_bit(CFLAG_TARGET_RESET, (ulong *)&hfcp->cmd_flags)
	     || test_bit(CFLAG_BUS_RESET, (ulong *)&hfcp->cmd_flags) )
	{
		/* Target Reset */
		fcp_cmd.fcp_cntl.task_mgm |= HFC_TARGET_RST;
	}
	else
	{
		/* FCP-CDB */
		HFC_MEMCPY(fcp_cmd.fcp_cdb, (uchar*)&(cmnd->cmnd[0]), cmnd->cmd_len);
	}

	/* FCP-CNTL Byte3 */
	if ( cmnd->sc_data_direction == SCSI_DATA_WRITE )
		fcp_cmd.fcp_cntl.data_type |= HFC_WRITE_DATA;	/* bit7 */
	else
		fcp_cmd.fcp_cntl.data_type |= HFC_READ_DATA;	/* bit6 */

	/* FCP-DL */
	/* fcp_cmd->fcp_data_len = cmnd->bufflen; */
	HFC_4L_TO_4B(fcp_cmd.fcp_dl, hfcp->data_size );

	/* Copy hfc_pkt to XOB */
	HFC_MEMCPY((fcp_cmd_iu_t *)(&ap->xob[hfcp->cmd_xob].fcp_cmd),
										&fcp_cmd, sizeof(struct fcp_cmd_iu));

	if (hfcp->seg_cnt == 0) {													/* FCLNX-0404 */
		if (hfcp->data_size == 0) {
			ap->controlrequests++;
		}
		else {
			if (cmnd->sc_data_direction == SCSI_DATA_WRITE) {
				ap->outputrequests++;
				ap->outputbytes += hfcp->data_size;
			}
			else if (cmnd->sc_data_direction == SCSI_DATA_READ) {
				ap->inputrequests++;
				ap->inputbytes += hfcp->data_size;
			}
		}
	}	
	else {
		if (cmnd->sc_data_direction == SCSI_DATA_WRITE) {
			ap->outputrequests++;
			ap->outputbytes += hfcp->data_size;
		}
		else if (cmnd->sc_data_direction == SCSI_DATA_READ) {
			ap->inputrequests++;
			ap->inputbytes += hfcp->data_size;
		}
	}																			/* FCLNX-0404 */

	return ;
}


/*
 * Function:    hfc_xob_enque
 *
 * Purpose:     Create xob
 *              Dequeue hfc_pkt from the wx_que and enqueue it to we_que
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  hfcp       - Pointer to hfc_pkt  
 *  target     - Pointer to target_info
 * Returns:     
 *  0          - No need for starting timer
 *
 * context:     user / kernel / interrupt
 *
 * Notes:		Lock adap_info before calling this function
 */
void hfc_xob_enque(struct adap_info *ap, struct target_info *target,
						 struct hfc_pkt *hfcp)
{
	struct xob			*xob_p ;
	uint				inp_num = 0 ;
	uint				inp_page = 0 ;
	uint				inp_entry = 0 ;
	uint				hash ;
	uint                        	fw_xob_inp;
	uint                        	work_xob_inp;
	uint                        	wk_inp_entry;
	uint                        	wk_inp_entry2;
	struct hfc_pkt		**we_que_top_p;
	struct hfc_pkt		**we_que_end_p;
	uint                d_info = 0;

	/* Caliculate sequential number of xob from fw_init_tbl.xob_inp */
	work_xob_inp = ap->fw_init_p->xob_inp;
	HFC_4B_TO_4L(fw_xob_inp, work_xob_inp);
	inp_num = ((fw_xob_inp & 0x00ff0000)>>16)*HFC_XOB_PER_PAGE ;
	inp_num += (fw_xob_inp & 0x0000ffff) ;

	ap->xob_no = (ushort)inp_num ;	

	xob_p = &ap->xob[ap->xob_no] ;
	
	/* XOB - Driver Used Area */
	memset(&xob_p->drv_work, 0, sizeof(xob_p->drv_work));
	xob_p->drv_work.hfc_pkt   = (unsigned long long) (ulong) hfcp ;	/*  */
	xob_p->drv_work.target_id = (ushort)(target->target_id & 0xffffffff) ;
	xob_p->drv_work.lun_id	  = (ushort) hfcp->lun_id;
	
	if( HFC_MMODE_CHECK_SHARED(ap)  && !(HFC_MMODE_CHECK_SHADOW(ap) ) )     /* FCLNX-0371 */
	{
		xob_p->drv_work.rid       = (uchar) ap->rid;
	}                                                                       /* FCLNX-0371 */
	
	/* XOB - DEST_INFO */
	d_info = (uint)(target->scsi_id & 0x00ffffff);
	if (ap->connect_type == HFC_AL)
		d_info |= (uint)((target->scsi_id & 0x000000ff)<<24);
	HFC_4L_TO_4B(xob_p->d_info, d_info);

	/* XOB - DEST_INFO */
	xob_p->pseq = target->pseq ;

	/* XOB - Class */
	HFC_2L_TO_2B(xob_p->class, target->fc_class);

	/* XOB - BURST_LEN */
	xob_p->burst_len = 0;

	/* XOB - FLAG,SKIP */
	xob_p->bflag = 0 ;
	xob_p->cflag = 0 ;
	xob_p->skip &= ~HFC_XOB_SKIP ;		/* Reset skip flag */
	xob_p->flag |= HFC_XOB_VALID ;		/* Set valid flag */

	/* Count up xob inp */
	ap->xob_no++ ;
	if( ap->xob_no >= ap->xob_max )
		ap->xob_no = 0 ;

	inp_page = ap->xob_no / HFC_XOB_PER_PAGE ;
	inp_entry = ap->xob_no % HFC_XOB_PER_PAGE ;
	wk_inp_entry = ((inp_page << 16) & 0x00ff0000) | (inp_entry & 0x0000ffff) ;
	HFC_4L_TO_4B(wk_inp_entry2, wk_inp_entry);
	ap->fw_init_p->xob_inp = wk_inp_entry2;

	/* Count up Xob execution wait count */
	ap->xob_wait_exec_cnt++ ;

#if _HFC_DEBUG_STRA_11
	/* Set timeout value */
	hfcp->cmd_timeout = gethrtime();				/* Read system timer */
																/* v1.32 STR */
	if (pkt->pkt_time)			
		wtime = pkt->pkt_time;						/* Unit of 1min 			*/
	else
		wtime = 24*60*60;							/* pkt_time=0 -> one day	*/

	hfcp->cmd_timeout += (wtime * 1000000000);	
#endif

	hfc_deque_wx_que(target, hfcp);

	hash = hfcp->lun_id % HASH_T_NUM;
	/* Enqueue wait_end_que */
	/* Move packet from wait_xob_que to wait_end_que. */
	we_que_top_p = &target->we_que_top[hash];
	we_que_end_p = &target->we_que_end[hash];

	if( *we_que_top_p == NULL )
	{
		/* Wait_end_que is empty */
		hfcp->cmd_forw = NULL;
		hfcp->cmd_prev = NULL;
		target->we_que_top[hash] = hfcp ;
		target->we_que_end[hash] = hfcp ;
		
	}
	else
	{
		/* Enqueue packet to the last of wait_end_que. */
		target->we_que_end[hash]->cmd_forw = (struct hfc_pkt *)hfcp ;
		hfcp->cmd_prev = (struct hfc_pkt *)target->we_que_end[hash] ;
		target->we_que_end[hash] = hfcp ;
				
		target->we_que_end[hash]->cmd_forw = NULL ;
	}
	target->we_que_cnt++;

	if ( hfc_manage_info.hfcldd_mp_mod && hfc_manage_info.lg_target_info && hfcp->dev)
		hfc_manage_info.npubp->hfc_queue_count(hfcp, 1, 0);	/* we enqueue */

	return ;
}


/*
 * Function:    hfc_enque_next_dstart
 *
 * Purpose:     Enqueue target to the next start target queue (ap->next_dstart)
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info *
 * Returns:     
 *
 *
 * Notes:		Lock adap_info before calling this function
 *				This function update following elements;
 * 			 		ap->next_dstart_top - The top of next start target queue
 *              	ap->next_dstart_end - The end of next start target queue
 *              	ap->next_dstart_cnt - Number of enqueued target
 *              	target->next_dstart_flag 
 *						- Flag means this target has already registered.
 */
void hfc_enque_next_dstart(struct adap_info *ap,struct target_info *target)
{

	if( target->next_dstart_flag )	/* Target has already registered in queue	*/
		return ;

	if( ap->next_dstart_cnt == 0 )
	{
		/* Enqueue to the empty queue */
		ap->next_dstart_top = target ;
		ap->next_dstart_end = target ;

		target->nnext = NULL ;
		target->nprev = NULL ;
	}
	else
	{
		/* Enqueue as a last element */
		ap->next_dstart_end->nnext = target ;
		target->nprev = ap->next_dstart_end ;
		ap->next_dstart_end = target ;
		target->nnext = NULL ;
	}

	hfc_watchdog_enter(ap, target, NULL, 0,HFC_WEXEC_TMR, 0, TRUE);		/* FCLNX-GPL-046	*/
	hfc_watchdog_enter(ap, target, NULL, 0,HFC_WEXEC_TMR, 0, FALSE);	/* FCLNX-GPL-046	*/
	ap->next_dstart_cnt++  ;
	target->next_dstart_flag = 1 ;
}

/*
 * Function:    hfc_deque_next_dstart
 *
 * Purpose:     Dequeue target from next start target queue (ap->next_dstart)
 *
 * Arguments:   
 *  ap          - Pointer to adap_info
 *  target      - Pointer to target_info *
 *
 * Returns:     -
 *
 * Notes:		Lock adap_info before calling this function
 *				This function update following elements;
 * 			 		ap->next_dstart_top - The top of next start target queue
 *              	ap->next_dstart_end - The end of next start target queue
 *              	ap->next_dstart_cnt - Number of enqueued target
 *              	target->next_dstart_flag 
 *						- Flag means this target has already registered.
 */
void hfc_deque_next_dstart(struct adap_info *ap,struct target_info *target)
{

	if( ap->next_dstart_cnt == 0 )		/* There is no target for dequeuing */
		return ;

	if( !target->next_dstart_flag ) 	/* This target is not enqueued	*/
		return ;									

	if( (target->wx_que_cnt == 0)		/* We_que empty? */
		&& (ap->xob_wait_exec_cnt != 0) /* Any xob waiting for execution? */
		&& (ap->next_dstart_cnt == 1) ) /* Any target waiting for initiation? */
	{
		target->next_dstart_flag = 2 ;
		return ;
	}

	if( ap->next_dstart_cnt == 1 )		/* The number of queue element is one */
	{
		ap->next_dstart_top = NULL ;
		ap->next_dstart_end = NULL ;
		ap->next_dstart_cnt = 0 ;
	}
	else
	{
		if( target == ap->next_dstart_top ) 	/* Dequeue from the top of the queue */
		{
			ap->next_dstart_top = target->nnext ;
			ap->next_dstart_top->nprev = NULL ;
			ap->next_dstart_cnt--;
		}
		else if( target == ap->next_dstart_end ) /* Dequeue from the last of the queue */
		{
			ap->next_dstart_end = target->nprev ;
			ap->next_dstart_end->nnext = NULL ;
			ap->next_dstart_cnt--;
		}
		else										/* Otherwise */
		{
			if( (target->nprev != NULL)
			 && (target->nnext != NULL) )
			{
				target->nprev->nnext = target->nnext ;
				target->nnext->nprev = target->nprev ;
				ap->next_dstart_cnt--;
			}
		}
	}

	target->nnext = NULL ;
	target->nprev = NULL ;
	target->next_dstart_flag = 0 ;
	hfc_watchdog_enter(ap, target, NULL, 0,HFC_WEXEC_TMR, 0, TRUE);		/* FCLNX-GPL-046	*/
}


/*
 * Function:    hfc_iodone
 *
 * Purpose:     Termination process of SCSI initiation.
 *
 * Arguments:   
 *  ap          - Pointer to adap_info
 *  cmnd        - Pointer to scsi_cmnd 
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_iodone(
	struct adap_info        *ap,
	struct scsi_cmnd        *cmnd,
	struct hfc_pkt          *hfcp )
{
	struct target_info		*target=NULL;
	uchar warning_msg=0,retry_internal=0,retryout=0,cmd_type=0,skip=0;	/* FCLNX-0244,0246 */
	struct target_info *wktg=NULL;

	if (hfcp != NULL)
	{
		/* Update iov only when normal SCSI initiation or IOCTL request occurs */
		if(	HFC_HFCP_CFLAG_TEST(CFLAG_SEGVALID, hfcp) )
		{
			if (hfcp->iov_cnt > 0)
			{
				hfc_iov_update(ap, hfcp->iov_no, hfcp->iov_cnt, 1);
			}
		}
		
		if (hfcp->seg_cnt)
		{
			pci_unmap_sg(ap->pci_cfginf, cmnd->request_buffer, cmnd->use_sg, 
				scsi_to_pci_dma_dir(cmnd->sc_data_direction));
		}
		else if(  (cmnd->request_bufflen )&&(hfcp->dma_handle) )
		{
			pci_unmap_page(ap->pci_cfginf,
					hfcp->dma_handle,
					cmnd->request_bufflen,
					scsi_to_pci_dma_dir(
					cmnd->sc_data_direction));
		}
		if ( test_bit(CFLAG_SCMD_SLOGV, (ulong *)&hfcp->cmd_flags) )
		{	/* Packet has MIHLOG */
			target = hfcp->target;
			if( test_bit(CFLAG_TIMEOUT, (ulong *)&hfcp->cmd_flags) )
			{
				memset( logdata, 0, 16 );
				memcpy( logdata, (uchar*)&ap->xob[ap->xob_no].fcp_cmd.fcp_cntl, 4 );
				hfc_errlog( ap, target, hfcp, HFC_ERRLOG_TYPE_NONE,
							 ERRID_HFCP_ERRA, 0x24, logdata, 16 );
			
				hfc_errlog( ap, target, hfcp, HFC_ERRLOG_TYPE_TOUTLOG,
					 ERRID_HFCP_EVNT3, 0x7f, NULL, 0 );				/* FCLNX-0494	*/
				
				clear_bit(CFLAG_SCMD_SLOGV, (ulong *)&hfcp->cmd_flags);
			}
			else
			{
				memset( logdata, 0, 16 );
				memcpy( logdata, (uchar*)&ap->xob[ap->xob_no].fcp_cmd.fcp_cntl, 4 );
				hfc_errlog( ap, target, hfcp, HFC_ERRLOG_TYPE_NONE,
							 ERRID_HFCP_ERRA, 0x26, logdata, 16 );
			
				hfc_errlog( ap, target, hfcp, HFC_ERRLOG_TYPE_TOUTLOG,
					 ERRID_HFCP_EVNT3, 0x7f, NULL, 0 );				/* FCLNX-0494	*/
				clear_bit(CFLAG_SCMD_SLOGV, (ulong *)&hfcp->cmd_flags);
			}
			
		}
		
		if ( !test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags) )			/* FCLNX-0554 STR */
		{
			cmnd->host_scribble = 0;
			
			if ((cmnd->device != NULL)
			 && (cmnd->device->type == TYPE_DISK))								/* FCLNX-0441 */
			{
				if( test_bit(CFLAG_TIMEOUT, (ulong *)&hfcp->cmd_flags) )
				{
					if(ap->scsi_to_retry > 0) {
						cmnd->allowed = ap->scsi_to_retry;						/* FCLNX-0523   */
					}
					else if ( cmnd->allowed < ap->scsi_allowed ){
						cmnd->allowed = ap->scsi_allowed;
					}
				}
				else if ( cmnd->allowed < ap->scsi_allowed ){
					cmnd->allowed = ap->scsi_allowed;
				}
			}
		}
		
#if _HFC_ERROR_INJ
		/*
		 * Pseudo FC Error injection process     
		 */
		if (CMND_TARGET(cmnd) == 0 && CMND_LUN(cmnd) == 1) {
			int fcerr_code = hfc_debug_ioerr_code;

			if (((fcerr_code > 0) && (fcerr_code < 100))
			 && (cmnd->cmnd[0] == 0x2A)) {
				static int fcerr_count = 0;
				int fcerr_issue        = 10000;
				int fcerr_num          = 100;

				if (fcerr_count == 0)
					HFC_ERRPRT("hfcldd : Wait I/O Error (fcerr_code=%d, err_max=%d).\n",fcerr_code, fcerr_num);
				
				if ((fcerr_count % 1000) == 0)
					HFC_ERRPRT("fcerr_count = %d /%d.\n",fcerr_count,fcerr_issue);
				
				if (fcerr_count < fcerr_issue)
				{
					fcerr_count++;
				}
				else if (fcerr_count > (fcerr_issue + fcerr_num)) {
					fcerr_count = 0;
				}
				else {
					if (cmnd->result & 0x00ff00ff) {
						HFC_ERRPRT("Unexpected I/O Error. (cmnd->result=0x%08x).\n", cmnd->result);
					}
					else {
						cmnd->result &= 0xFF00FFFF;
						
						switch (fcerr_code) {
							case 1   : cmnd->result |= (DID_NO_CONNECT << 16);	break;
							case 2   : cmnd->result |= (DID_BUS_BUSY << 16);	break;
							case 3   : cmnd->result |= (DID_TIME_OUT << 16);	break;
							case 4   : cmnd->result |= (DID_BAD_TARGET << 16);	break;
							case 5   : cmnd->result |= (DID_ABORT << 16);		break;
							case 6   : cmnd->result |= (DID_PARITY << 16);		break;
							case 7   : cmnd->result |= (DID_ERROR << 16);		break;
							case 8   : cmnd->result |= (DID_RESET << 16);		break;
							case 9   : cmnd->result |= (DID_BAD_INTR << 16);	break;
							case 10  : cmnd->result |= (DID_PASSTHROUGH << 16);	break;
							case 11  : cmnd->result |= (DID_SOFT_ERROR << 16);	break;
							default  : HFC_ERRPRT("Illigal _HFC_ERROR_INJ( value=%d? ).\n",fcerr_code);
						}
						
					}
					fcerr_count++;
				}
			}
		}
#endif																			/* FCLNX-0554 END */

		if ( test_bit(CFLAG_ABORT, (ulong *)&hfcp->cmd_flags )
		  || test_bit(CFLAG_LUN_RESET, (ulong *)&hfcp->cmd_flags ) 
		  || test_bit(CFLAG_TARGET_RESET, (ulong *)&hfcp->cmd_flags ) 
		  || test_bit(CFLAG_BUS_RESET, (ulong *)&hfcp->cmd_flags ) )
		{
			if ( test_bit(CFLAG_TARGET_RESET, (ulong *)&hfcp->cmd_flags)
			  || test_bit(CFLAG_BUS_RESET, (ulong *)&hfcp->cmd_flags) )
				hfc_watchdog_enter( ap, hfcp->target, hfcp, 0, HFC_TARGET_RST_TMR, 0, TRUE );
			else
				hfc_watchdog_enter( ap, hfcp->target, hfcp, 0, HFC_ABORT_TMR, 0, TRUE );
			
			if ( hfc_manage_info.hfcldd_mp_mod && hfc_manage_info.lg_target_info ) {
				hfc_manage_info.npubp->hfc_ioerror_check(cmnd, hfcp);

				if ( !hfc_manage_info.npubp->hfc_check_io_reset_complete(hfcp) ) {	/* FCLNX-0606 */
					return;			/* continue reset process */
				}
			}
			
			if ( !test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags) ) {		/* only hsdldd */
				HFC_DBGPRT(KERN_ERR " hfcldd : hfc_iodone - CFLAG_ABORT \n");
#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,16)
				clear_bit(CMND_VALID, (ulong *)&cmnd->sc_magic);
#else
				clear_bit(CMND_VALID, (ulong *)&cmnd->eh_eflags);
#endif
				ap->cmnd_cnt--;
				clear_bit(CFLAG_VALID, (ulong *)&hfcp->cmd_flags);
				ap->pkt_cnt--;

				if(cmnd->device != NULL) kfree(cmnd->device);
			}
			else {
				if ( cmnd->scsi_done != NULL )
#ifdef	HFC_DEBUG_IODONE	/* FCLNX-0616 */
			hfc_stra_trace(HFC_TRC_IODONE ,0x11 ,ap ,target , hfcp, (ulong)cmnd, 0, 0);
#endif /* HFC_DEBUG_IODONE */	/* FCLNX-0616 */
					cmnd->scsi_done(cmnd);
			}
		}
		else 
		{
			hfc_watchdog_enter( ap, hfcp->target, hfcp, 0, HFC_SCSI_CMD_TMR, 0, TRUE );
			
			if ( test_bit(CFLAG_TIMEOUT, (ulong *)&hfcp->cmd_flags ) )
			{
				HFC_DBGPRT(" hfcldd : hfc_iodone - Skip iodone (CFLAG_TIMEOUT) \n");
				cmnd->result &= 0xff00ffff;
				cmnd->result |= (DID_TIME_OUT << 16);
			}
			else if ( (hfcp->target != NULL) && test_bit(HFC_WAIT_DEVRSP, (ulong *)&hfcp->target->status) )
			{
				HFC_DBGPRT(" hfcldd : hfc_iodone - Skip iodone (HFC_WAIT_DEVRSP) \n");
				cmnd->result &= 0xff00ffff;
				cmnd->result |= DID_RESET << 16;
			}
			else if ( test_bit( HFC_WAIT_BUSRSP, (ulong *)&ap->status ) )
			{
				HFC_DBGPRT(" hfcldd : hfc_iodone - Skip iodone (HFC_WAIT_BUSRSP) \n");
				cmnd->result &= 0xff00ffff;
				cmnd->result |= DID_RESET << 16;
			}

			skip = 0;
			if (( hfc_manage_info.hfcldd_mp_mod ) &&
				( hfc_manage_info.lg_target_info ) &&
				( hfc_manage_info.npubp->hfc_attribute_check(cmnd, ap) )) {
				if (hfc_manage_info.npubp->hfc_mp_iodone(cmnd, ap, hfcp)) {
					if (!test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags) )
						return;
				}
			}
			
			if (test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags) )
				skip = 1;
			
			if ( cmnd->result && !skip ) {		/* FCLNX-0244 STR */
				cmd_type = 0;
				switch (cmnd->cmnd[0]) {
					case WRITE_6               : cmd_type = 3; break;
					case WRITE_FILEMARKS       : cmd_type = 3; break;
					case RECOVER_BUFFERED_DATA : cmd_type = 3; break;
					case COPY                  : cmd_type = 3; break;
					case ERASE                 : cmd_type = 3; break;
					case WRITE_10              : cmd_type = 3; break;
					case WRITE_VERIFY          : cmd_type = 3; break;
					case SYNCHRONIZE_CACHE     : cmd_type = 3; break;
					case COPY_VERIFY           : cmd_type = 3; break;
					case WRITE_BUFFER          : cmd_type = 3; break;
					case WRITE_LONG            : cmd_type = 3; break;
					case WRITE_SAME            : cmd_type = 3; break;
					case WRITE_12              : cmd_type = 3; break;
					case WRITE_VERIFY_12       : cmd_type = 3; break;
					case WRITE_LONG_2          : cmd_type = 3; break;
					
					case INQUIRY               : cmd_type = 1; break;			/* FCLNX-0327 */
					case 0xA0                  : cmd_type = 1; break;			/* FCLNX-0327 */
					case READ_CAPACITY         : cmd_type = 1; break;			/* FCLNX-0327 */
					
					default                    : cmd_type = 0;
				}
				
				if (cmd_type == 1)			/* CHECK COMMAND  */				/* FCLNX-0327 */
				{																/* FCLNX-0327 */
					if ( (((cmnd->result >> 16) & 0xff) == DID_TIME_OUT )		/* FCLNX-0327 */
					  && !test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags) )
					{															/* FCLNX-0327 */
						/* Need command retry */								/* FCLNX-0327 */
						cmnd->result &= 0xff00ffff;								/* FCLNX-0327 */
						cmnd->result |= (DID_ERROR << 16);	/* retry */			/* FCLNX-0327 */
					}															/* FCLNX-0327 */
				}																/* FCLNX-0327 */
				else if ((cmd_type == 3)		/* WRITE COMMAND */				/* FCLNX-0327 */
					&& !test_bit(CFLAG_COMMAND_DEV, (ulong *)&hfcp->cmd_flags) )/* FCLNX-0611 */
				{																/* FCLNX-0611 */
					warning_msg = FALSE;										/* FCLNX-0246 */
					retry_internal = FALSE;										/* FCLNX-0246 */
					retryout = FALSE;
					
					if (hfc_manage_info.lg_target_info == NULL)
						wktg = hfcp->target;
					else
						wktg = hfc_hash_target_valid(ap, CMND_TARGET(cmnd));
					
					if ((wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)])) {
						if (wktg->write_retries[CMND_LUN(cmnd)] == 0x80) {		/* retry  */
							cmnd->retries = 0;
							cmnd->allowed = 10;
							hfcp->fail = 0;										/* FCLNX-0246 */
						}
						else if (wktg->write_retries[CMND_LUN(cmnd)] == 0xff);	/* retry(default) */
						else 
						{
							int rcnt = wktg->write_retries[CMND_LUN(cmnd)] & 0x7f;
							
							if (cmnd->allowed != rcnt) {						/* FCLNX-0327 */
								if (cmnd->allowed != ap->scsi_allowed) {		/* FCLNX-0327 */
									hfc_errlog(ap, NULL, hfcp, HFC_ERRLOG_TYPE_IODONE_WARN1, ERRID_HFCP_EVNT3, 0x93, NULL, 0) ;
								}
								cmnd->allowed = rcnt;
							}
						}
					}
					
					switch ( (cmnd->result >> 16) & 0xff)
					{
						/* no retry */
						case DID_NO_CONNECT :	/* Couldn't connect before timeout period  */
						case DID_TIME_OUT   :	/* TIMED OUT for other reason              */
							warning_msg = TRUE;										/* FCLNX-0246 */
							
							if ((wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)])) {
								retry_internal = TRUE;								/* FCLNX-0246 */
								
								if ( hfcp->fail >= cmnd->allowed)				/* FCLNX-0246 */
									retryout = TRUE;
							}
							else {
									retryout = TRUE;
							}
							break;
							
						/* use retries */
						case DID_RESET      :	/* Reset by somebody.                      */
						case DID_BUS_BUSY   :	/* BUS remain busy through time out period */
						case DID_PARITY     :	/* Parity error                            */
						case DID_ERROR      :	/* Internal error                          */
						case DID_SOFT_ERROR :	/* The low level driver just wish a retry  */
							warning_msg = TRUE;										/* FCLNX-0246 */
							if ((wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)])) {
                                                                retry_internal = TRUE;                                                        /* FCLNX-0246 */ /* FCLNX-0631 */
								if ( hfcp->fail >= cmnd->allowed)
								retryout = TRUE;
							}	/* FCLNX-0631 */
							else{
								if ( hfcp->fail >= cmnd->allowed)
                                                                        retryout = TRUE;
                                                        }       /* FCLNX-0631 */
							break;
							
						case DID_OK         :	/* Normal end                              */
							if (((cmnd->result & STATUS_MASK)>>1) != CHECK_CONDITION)
								break;
							
							if ( ((cmnd->sense_buffer[2] & 0xf) == NOT_READY)	/* FCLNX-0246 */
							  || ((cmnd->sense_buffer[2] & 0xf) == MEDIUM_ERROR)
							  || ((cmnd->sense_buffer[2] & 0xf) == ABORTED_COMMAND) )
							{
								warning_msg = TRUE;								/* FCLNX-0246 */
								
								if ((wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)])) {
									retry_internal = TRUE;						/* FCLNX-0246 */
									
									if ( hfcp->fail >= cmnd->allowed)		/* FCLNX-0246 */
										retryout = TRUE;
								}
								else {
									if ( hfcp->fail >= cmnd->allowed)
										retryout = TRUE;
								}
							}
							else if ((cmnd->sense_buffer[2] & 0xf) == HARDWARE_ERROR)
							{
								warning_msg = TRUE;								/* FCLNX-0246 */
								
								if ((wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)])) {
									retry_internal = TRUE;						/* FCLNX-0246 */
									
									if ( hfcp->fail >= cmnd->allowed)		/* FCLNX-0246 */
										retryout = TRUE;
								}
								else {
									retryout = TRUE;
								}
							}
							break;
							
						default :
							/* DID_ABORT       */	/* Failed Abort request                    */
							/* DID_BAD_TARGET  */	/* No target						       */
							/* DID_BAD_INTR    */	/* Got an interrupt we did not expect	   */
							/* DID_PASSTHROUGH */	/* Force command past mid-layer            */
							break;
					}
				}																/* FCLNX-0244 END */
				if ( ((cmnd->result >> 16) & 0xff) == DID_TIME_OUT ) {			/* FCLNX-0404 */
					ap->scsi_timeout_fail++;									/* FCLNX-0404 */
					
					if ( !ap->scsi_time_out
					  && !test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags)) {
						cmnd->result &= 0xff00ffff;
						cmnd->result |= (DID_ERROR << 16);
					}
				}
				if (cmd_type == 3)		/* WRITE COMMAND */					/* FCLNX-0327 */
				{
					if (warning_msg == TRUE)									/* FCLNX-0246 STR */
					{
						if ( ((wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)]))
						  || (ap->wmsg && (retryout == TRUE)) ) {
							hfc_errlog(ap, NULL, hfcp, HFC_ERRLOG_TYPE_IODONE_WARN2, ERRID_HFCP_EVNT3, 0x93, NULL, 0) ;
							if ((wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)] == 0x80)) {
								hfc_errlog(ap, NULL, hfcp, HFC_ERRLOG_TYPE_IODONE_WARN3, ERRID_HFCP_EVNT3, 0x93, NULL, 0) ;
							}
							else if (retry_internal == TRUE) {
								hfc_errlog(ap, NULL, hfcp, HFC_ERRLOG_TYPE_IODONE_WARN4, ERRID_HFCP_EVNT3, 0x93, NULL, 0) ;
							}
							else {
								hfc_errlog(ap, NULL, hfcp, HFC_ERRLOG_TYPE_IODONE_WARN5, ERRID_HFCP_EVNT3, 0x93, NULL, 0) ;
							}
						}

						if ( (wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)]) )
						{
							if (retryout == TRUE) {
								HFC_ERRPRT(" DONE LAST RETRY. GIVE UP!\n");

								if ((wktg != NULL) && (wktg->write_retries[CMND_LUN(cmnd)] > 0x80))
								{
									panic("DONE LAST RETRY");
								}
							}
							else if (retry_internal == TRUE)			/* Enqueue internal retry */
							{
								hfcp->cmd_forw = NULL;
								hfcp->cmd_prev = NULL;
								
								if (ap->retry_hfcp_top == NULL) {
									ap->retry_hfcp_top = hfcp;
									ap->retry_hfcp_end = hfcp;
								}
								else {
									hfcp->cmd_prev = ap->retry_hfcp_end;
									ap->retry_hfcp_end->cmd_forw = hfcp;
									ap->retry_hfcp_end = hfcp;
								}
								ap->retry_hfcp_count++;
								return;
							}
							
						}
					}
				}
			}

			if ( cmnd->scsi_done != NULL ) {
#ifdef	HFC_DEBUG_IODONE	/* FCLNX-0616 */
			hfc_stra_trace(HFC_TRC_IODONE ,0x10 ,ap ,target , hfcp, (ulong)cmnd, 0, 0);
#endif /* HFC_DEBUG_IODONE */	/* FCLNX-0616 */
				cmnd->scsi_done(cmnd);
			}

			if ( !test_bit(CFLAG_HSDLDD_VALID, (ulong *)&hfcp->cmd_flags) )		/* only hsdldd */
				ap->pkt_cnt--;
			
			ap->scsi_end_cnt++;
			clear_bit(CFLAG_VALID, (ulong *)&hfcp->cmd_flags);
		}
	}
	else
	{
		if ( cmnd->scsi_done != NULL ) {
#ifdef	HFC_DEBUG_IODONE	/* FCLNX-0616 */
			hfc_stra_trace(HFC_TRC_IODONE ,0x12 ,ap ,target , NULL, (ulong)cmnd, 0, 0);
#endif /* HFC_DEBUG_IODONE */	/* FCLNX-0616 */
			cmnd->scsi_done(cmnd);
		}
	}

}

/*--------------------------------------------------------------------------*/
#if 0
/*
 * Function:    hfc_seg_info_scatter
 *
 * Purpose:     Devide seg_info for debug (8k Byte or more * 1)
 *
 * Arguments:   
 *  ap         - Pointer to adap_info
 *
 * Returns:     
 *
 * Notes:       1.43 for FW_DEBUG
 */
void hfc_seg_info_scatter(struct adap_info *ap)
{
	struct xob 			*xob_p ;
	int					seg_info_no , seg_info_befor ;
	int					length ;
	int 				i ;
	unsigned long long	addr ;
	unsigned long long	addr_mask ;
	int					bdy ;
	
	xob_p = &ap->xob[ap->xob_no-1] ;		/*-- Xob pointer fixation		--*/
	seg_info_no = ap->iov_no + (ap->iov_no / HFC_SEG_PER_PAGE) ;
	seg_info_befor = seg_info_no ;
	length = xob_p->seg_info_xob[0].seg_len & HFC_SEL_LEN_MASK ;
	
	if( xob_p->seg_info_xob[0].seg_len & HFC_SEG_LEN_L )
	{
		if( length > 0x20000 )
		{
			/*-- 128k or more  --> It divides by 64k boundary --*/
			bdy = 0x10000 ;
			addr_mask = 0xffffffffffff0000 ;
		}
		else if( length > 0x10000 )
		{
			/*-- From 4k to 128k --> It divides by 32k boundary --*/
			bdy = 0x8000 ;
			addr_mask = 0xffffffffffff8000 ;
		}
		else if( length > 0x8000 )
		{
			/*-- From 32k to 64k --> It divides by 16k boundary --*/
			bdy = 0x4000 ;
			addr_mask = 0xffffffffffffc000 ;
		}
		else if( length > 0x2000 )
		{
			/*-- From 8k to 32k --> It divides by 8k boundary --*/
			bdy = 0x2000 ;
			addr_mask = 0xffffffffffffe000 ;
		}
		else return ;
		i = 0 ;
		while( length > 0 )
		{
			if( i == 0 )
			{
				addr = xob_p->seg_info_xob[0].seg_addr + (unsigned long long)bdy  ;
				addr &= addr_mask ;
				xob_p->seg_info_xob[0].seg_len = addr - xob_p->seg_info_xob[0].seg_addr ;
				if( ap->seg_info[seg_info_no].seg_len & HFC_SEG_LEN_F )
					seg_info_no++ ;
				ap->seg_info[seg_info_no].seg_len = xob_p->seg_info_xob[0].seg_len ;
				length -= ap->seg_info[seg_info_no].seg_len ;
				i++ ;

				xob_p->seg_info_xob[1].seg_addr = addr ;
				xob_p->seg_info_xob[1].xob_segno = xob_p->seg_info_xob[0].xob_segno + 1 ;
				seg_info_befor = 0 ;
				if( ap->seg_info[seg_info_no+1].seg_len & HFC_SEG_LEN_F )
				{
					seg_info_befor = 1 ;
					seg_info_no++ ;
				}
				ap->seg_info[seg_info_no+1].seg_addr = addr ;
				ap->seg_info[seg_info_no+1].xob_segno = ap->seg_info[seg_info_no-seg_info_befor].xob_segno + 1 ;
				if( length <= bdy )
				{
					xob_p->seg_info_xob[1].seg_len = length | HFC_SEG_LEN_L ;
					ap->seg_info[seg_info_no+1].seg_len = length | HFC_SEG_LEN_L ;
				}
				else
				{
					xob_p->seg_info_xob[1].seg_len = bdy ;
					ap->seg_info[seg_info_no+1].seg_len = bdy ;
				}
				length -= ap->seg_info[seg_info_no+1].seg_len ;
				i++ ;
				if( length <= 0 ) break ;
			}
			seg_info_befor = 1 ;
			if( ap->seg_info[seg_info_no+i].seg_len & HFC_SEG_LEN_F )
			{
				seg_info_befor = 2 ;
				seg_info_no++ ;
			}
			ap->seg_info[seg_info_no+i].seg_addr = ap->seg_info[seg_info_no+i-seg_info_befor].seg_addr + bdy ;
			ap->seg_info[seg_info_no+i].xob_segno = ap->seg_info[seg_info_no+i-seg_info_befor].xob_segno + 1 ;
			if( length <= bdy )
				ap->seg_info[seg_info_no+i].seg_len = length | HFC_SEG_LEN_L ;
			else
				ap->seg_info[seg_info_no+i].seg_len = bdy ;
			length -= ap->seg_info[seg_info_no+i].seg_len ;
			i++ ;
		}
		xob_p->seg_cnt = i ;

		if( seg_info_no+i > 6 )
			memcpy(&trcbuf[16],(uchar *)&ap->seg_info[seg_info_no-7],112);
		else
			memcpy(&trcbuf[16],(uchar *)&ap->seg_info[0],112);
		
		hfc_trace(ap,0xfa,&trcbuf[1],0);
	}	
}
#endif


/*
 * Function:    hfc_stra_trace
 *
 * Purpose:     Collection of trace
 *
 * Arguments:   
 *  id         - 
 *  sub_id     - 
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info 
 *  hfcp       - Pointer to hfc_pkt 
 *  etc1       - 
 *  etc2       - 
 *  etc3       - 
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_stra_trace(uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt	*hfcp,
					unsigned long long 	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3)
{
	uchar trc_wk[128], lun=0 ;
	struct trc_com *trc_com ;
	struct scsi_cmnd		*cmnd;

	HFC_BZERO(trc_wk,sizeof(trc_wk)) ;					/* Clear work area */
	trc_com = (struct trc_com *) trc_wk;

	trc_com->id 		= id;
	trc_com->sub_id 	= sub_id ;

	/*-- Target ID/LU setting --*/
	if ( hfcp != NULL )
	{
		cmnd = hfcp->cmd_pkt;
		if( cmnd != NULL)
		{
			HFC_2L_TO_2B(trc_com->target_id, hfcp->target_id) ;
			trc_com->lun_id		= (uchar)hfcp->lun_id ;
			trc_com->cmnd = (uchar)cmnd->cmnd[0];
			trc_com->timeout = (uchar)(cmnd->timeout_per_command/HZ);
			trc_com->use_sg = (uchar)cmnd->use_sg;
		}
	}
	if ( target != NULL )
	{
		HFC_2L_TO_2B(trc_com->target_id, target->target_id) ;
	}

	lun = trc_com->lun_id ;

	if ( target != NULL )
	{
		HFC_4L_TO_4B(trc_com->target_status, target->status) ;
		trc_com->target_flags		= target->flags ;
		trc_com->target_pseq		= target->pseq ;
		HFC_2L_TO_2B(trc_com->target_dev_flags, target->device_flags) ;
		trc_com->lunstat			= target->lustat[lun] ;
	}

	if ( ap != NULL )
	{
		HFC_4L_TO_4B(trc_com->adap_status, ap->status) ;
		trc_com->open_status = ap->open_status ;
	}

	switch (id)
	{
		case HFC_TRC_STRATEGY :
		case HFC_TRC_ABORT :
		case HFC_TRC_RESET :
		case HFC_TRC_BUS_RESET :
		case HFC_TRC_ISSUE_TMGM :
		case HFC_TRC_RST_NF :
		case HFC_TRC_RST_CBACK :
		case HFC_TRC_RST_FREE :
		case HFC_TRC_IODONE :
			hfc_stra_trc1(trc_wk,id,sub_id,ap,target,hfcp,etc1,etc2,etc3);
			break;

		case HFC_TRC_START :
			hfc_stra_trc2(trc_wk,id,sub_id,ap,target,hfcp,etc1,etc2,etc3);
			break;

		case HFC_TRC_CAN_XOB :
		case HFC_TRC_CAN_WE :
		case HFC_TRC_CAN_WX :
			hfc_stra_trc3(trc_wk,id,sub_id,ap,target,hfcp,etc1,etc2,etc3);
			break;

		case HFC_TRC_RES_CHK :
		case HFC_TRC_IOVUP :
		case HFC_TRC_DMA_MAP :
			hfc_stra_trc4(trc_wk,id,sub_id,ap,target,hfcp,etc1,etc2,etc3);
			break;

		case HFC_TRC_MK_CMD :
		case HFC_TRC_ENQ_XOB :
		case HFC_TRC_ENQ_WX :
			hfc_stra_trc5(trc_wk,id,sub_id,ap,target,hfcp,etc1,etc2,etc3);
			break;
	}

	hfc_trace(ap,id,&trc_wk[1],0) ;					/* Trace output */
}


/*
 * Function:    hfc_stra_trc1
 *
 * Purpose:     
 *
 * Arguments:   
 *  trc_wk     - 
 *  id         - 
 *  sub_id     - 
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info 
 *  hfcp       - Pointer to hfc_pkt 
 *  etc1       - 
 *  etc2       - 
 *  etc3       - 
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_stra_trc1( uchar	 *trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3)
{
	struct stra_trc1 *trc1 = (struct stra_trc1 *)trc_wk;
	struct scsi_cmnd *cmnd;
	uint	pkt_time;
	uint    a_scsi_id;
	uint    d_scsi_id;
	uint	ser_num;

	/*-- etc1 : s_bp	  --*/
	/*-- etc2 : type flag --*/
	/*-- etc3 : done flag --*/
	if ( ap != NULL )
	{
		a_scsi_id = (uint)ap->scsi_id;
		HFC_4L_TO_4B(trc1->a_scsi_id, a_scsi_id) ;				/* adaptor scsi_id */
		HFC_8L_TO_8B(trc1->scsi_exec_cnt, ap->scsi_exec_cnt) ;	/* Number of SCSI activate requests */
		HFC_8L_TO_8B(trc1->scsi_end_cnt, ap->scsi_end_cnt) ;	/* Number of SCSI responses */
		HFC_8L_TO_8B(trc1->scsi_err_cnt, ap->scsi_err_cnt) ;	/* Number of abnormal terminations */ 
																/*  of scsi command */
	}

	if ( target != NULL )
	{
		d_scsi_id = (uint)target->scsi_id;
		HFC_4L_TO_4B(trc1->d_scsi_id, d_scsi_id) ;				/* target  scsi_id */
		HFC_2L_TO_2B(trc1->wx_que_cnt, target->wx_que_cnt) ;	/* Scsi wx_que count */
		HFC_2L_TO_2B(trc1->we_que_cnt, target->we_que_cnt) ;	/* Scsi we_que count*/
	}

	if ( hfcp != NULL )
	{
		cmnd = hfcp->cmd_pkt;
//		trc1->cmd_status	= hfcp->cmd_pkt->result ;			/* hfc_pkt Status information */
		HFC_2L_TO_2B(trc1->cmd_xob, hfcp->cmd_xob) ;			/* hfc_pkt allocation xob# */
//		trc1->cmd_timeout	= hfcp->cmd_timeout ;				/* hfc_pkt timeout time */
		HFC_4L_TO_4B(trc1->cmd_flags, hfcp->cmd_flags) ;		/* hfc_pkt control flag  */
		HFC_4L_TO_4B(trc1->cmd_iov_no, hfcp->iov_no) ;			/* hfc_pkt - seg_info#	*/
		HFC_4L_TO_4B(trc1->cmd_iov_cnt, hfcp->iov_cnt) ;		/* hfc_pkt - number of seg_info */
		HFC_4L_TO_4B(trc1->adap_status, hfcp->adap_status) ;	/* hfc_pkt adap_status */
		if( cmnd != NULL )
		{
			trc1->pkt_flag = 0;
			pkt_time = cmnd->timeout_per_command/HZ;
			HFC_4L_TO_4B(trc1->pkt_time, pkt_time) ;		/* struct scsi_cmnd time set value */
			HFC_4L_TO_4B(trc1->pkt_resid, cmnd->resid) ;	/* struct scsi_cmnd remainder byte */
//			HFC_4L_TO_4B(trc1->pkt_state, cmnd->state) ;	/* struct scsi_cmnd state */ /* FCLNX-0308 */
			ser_num = (uint)cmnd->serial_number;
			HFC_4L_TO_4B(trc1->serial_number, ser_num) ;	/* struct scsi_cmnd serial_number */
			HFC_4L_TO_4B(trc1->pkt_result, cmnd->result) ;	/* struct scsi_cmnd result */
		}
	}
}


/*
 * Function:    hfc_stra_trc2
 *
 * Purpose:     
 *
 * Arguments:   
 *  trc_wk     - 
 *  id         - 
 *  sub_id     - 
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info 
 *  hfcp       - Pointer to hfc_pkt 
 *  etc1       - 
 *  etc2       - 
 *  etc3       - 
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_stra_trc2( uchar	*trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3)
{

	struct stra_trc2 *trc2 = (struct stra_trc2 *)trc_wk;
	uint 	i;
	uint a_scsi_id, d_scsi_id;
	uint 	timeout;

	/*-- etc1 : cmnd --*/
	/*-- etc2 : NULL --*/
	/*-- etc3 : NULL --*/
	if( ap != NULL )
	{
		a_scsi_id = (uint)ap->scsi_id;
		HFC_2L_TO_2B(trc2->xob_no, ap->xob_no) ;
		trc2->xob_exec_cnt 		= ap->xob_exec_cnt ;
		trc2->xob_wait_exec_cnt = ap->xob_wait_exec_cnt ;
		HFC_4L_TO_4B(trc2->iov_no, ap->iov_no) ;
		HFC_4L_TO_4B(trc2->iov_map_cnt, ap->iov_map_cnt) ;
		i = ap->frame_inp;
		if(i == 0)
			i = MAX_FRAME_CNT-1;
		else i--;
		HFC_4L_TO_4B(trc2->save_xob_outp, ap->save_xob_outp[ i ]) ;
		HFC_4L_TO_4B(trc2->xob_outp_end, ap->xob_outp_end[ i ]) ;
		trc2->xob_outp		= ap->fw_init_p->xob_outp;
		trc2->xob_inp		= ap->fw_init_p->xob_inp;
		HFC_8L_TO_8B(trc2->new_login_need, ap->login_target) ;
		HFC_8L_TO_8B(trc2->next_dstart_cnt, ap->next_dstart_cnt) ;
		HFC_4L_TO_4B(trc2->frame_chkp, ap->frame_chkp) ;
		i = ap->frame_inp;
		if(i == 0)
			i = MAX_FRAME_CNT-1;
		else i--;
		HFC_4L_TO_4B(trc2->frame_inp, i) ;
	}
	if ( target != NULL )
	{
		d_scsi_id = (uint)target->scsi_id;
		HFC_4L_TO_4B(trc2->d_scsi_id, d_scsi_id) ;		/* target  scsi_id 		*/
		HFC_2L_TO_2B(trc2->wx_que_cnt, target->wx_que_cnt) ;	/* scsi Start waiting count */
		HFC_2L_TO_2B(trc2->we_que_cnt, target->we_que_cnt) ;	/* scsi Response waiting count */
	}

	if ( hfcp != NULL )
	{
//		trc2->cmd_status	= hfcp->cmd_status ;	/* hfc_pkt Status information*/
		HFC_2L_TO_2B(trc2->cmd_xob, hfcp->cmd_xob) ;		/* hfc_pkt Allocation xob # 	*/
		if( hfcp->cmd_pkt != NULL){
			timeout = hfcp->cmd_pkt->timeout_per_command/HZ;
			HFC_4L_TO_4B(trc2->cmd_timeout, timeout) ;	/* hfc_pkt timeout time 	*/
			trc2->cmnd = (uchar)hfcp->cmd_pkt->cmnd[0];
		}
//		trc2->cmd_timeout	= (uint64_t)hfcp->cmd_timeout.dog.expires ;	/* hfc_pkt timeout time 	*/
		HFC_4L_TO_4B(trc2->cmd_flags, hfcp->cmd_flags) ;		/* hfc_pkt control flag  	*/
		HFC_4L_TO_4B(trc2->cmd_iov_no, hfcp->iov_no) ;			/* hfc_pkt - seg_info#	*/
		HFC_4L_TO_4B(trc2->cmd_iov_cnt, hfcp->iov_cnt) ;		/* hfc_pkt - number of seg_info */
		HFC_4L_TO_4B(trc2->cmd_data_size, hfcp->data_size) ;	/* hfc_pkt - data_size  */
		HFC_4L_TO_4B(trc2->adap_status, hfcp->adap_status) ;	/* hfc_pkt adap_status 	*/
	}
}


/*
 * Function:    hfc_stra_trc3
 *
 * Purpose:     
 *
 * Arguments:   
 *  trc_wk     - 
 *  id         - 
 *  sub_id     - 
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info 
 *  hfcp       - Pointer to hfc_pkt 
 *  etc1       - 
 *  etc2       - 
 *  etc3       - 
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_stra_trc3( uchar	*trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3)
{
	struct stra_trc3 *trc3 = (struct stra_trc3 *)trc_wk;

	/*-- etc1 : NULL --*/
	/*-- etc2 : type --*/
	/*-- etc3 : NULL --*/
	if( ap != NULL )
	{
		HFC_8L_TO_8B(trc3->a_scsi_id, ap->scsi_id) ;				/* adaptor scsi_id */
		trc3->xob_outp = ap->fw_init_p->xob_outp;
		trc3->xob_inp	= ap->fw_init_p->xob_inp ;
	}
	if( target != NULL )
	{
		HFC_8L_TO_8B(trc3->d_scsi_id, target->scsi_id) ;			/* target  scsi_id */
		HFC_4B_TO_4L(trc3->we_que_cnt, target->we_que_cnt) ;		/* v1.35   */
		HFC_4B_TO_4L(trc3->wx_que_cnt, target->wx_que_cnt) ;		/* v1.35   */
	}

	if( hfcp != NULL )
	{
	}

	trc3->type			= etc1 ;							/* cancel type 	*/
	trc3->lun			= etc2 ;							/* lun#		 	*/
	HFC_4B_TO_4L(trc3->adap_status, etc3) ;			/* adap_status	*/

}


/*
 * Function:    hfc_stra_trc4
 *
 * Purpose:     
 *
 * Arguments:   
 *  trc_wk     - 
 *  id         - 
 *  sub_id     - 
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info 
 *  hfcp       - Pointer to hfc_pkt 
 *  etc1       - 
 *  etc2       - 
 *  etc3       - 
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_stra_trc4( uchar	*trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3)
{
	struct stra_trc4 *trc4 = (struct stra_trc4 *)trc_wk;
	uint	a_scsi_id;
	int		i;

	/*-- etc1 : s_bp/type/s_bp		--*/
	/*-- etc2 : NULL/pos/rc 		--*/
	/*-- etc3 : NULL/cnt/NULL		--*/
	if( ap != NULL )
	{
		
		a_scsi_id = (uint)ap->scsi_id;
		HFC_4L_TO_4B(trc4->a_scsi_id, a_scsi_id);			/* adaptor scsi_id */
		trc4->xob_outp		= ap->fw_init_p->xob_outp;
		trc4->xob_inp		= ap->fw_init_p->xob_inp ;
		trc4->xob_exec_cnt 		= ap->xob_exec_cnt ;
		trc4->xob_wait_exec_cnt = ap->xob_wait_exec_cnt ;
		HFC_4B_TO_4L(trc4->xob_no, ap->xob_no);
		HFC_4B_TO_4L(trc4->iov_no, ap->iov_no);
		HFC_4B_TO_4L(trc4->iov_map_cnt, ap->iov_map_cnt);
		i = ap->frame_inp;
		if(i == 0)
			i = MAX_FRAME_CNT-1;
		else i--;
		HFC_4L_TO_4B(trc4->save_xob_outp, ap->save_xob_outp[ i ]) ;
		HFC_4L_TO_4B(trc4->xob_outp_end, ap->xob_outp_end[ i ]) ;
		HFC_4L_TO_4B(trc4->frame_chkp, ap->frame_chkp) ;
		i = ap->frame_inp;
		if(i == 0)
			i = MAX_FRAME_CNT-1;
		else i--;
		HFC_4L_TO_4B(trc4->frame_inp, i) ;
	}

	if ( target != NULL )
	{
		HFC_2L_TO_2B(trc4->wx_que_cnt, target->wx_que_cnt) ;	/* scsi start waiting count */
		HFC_2L_TO_2B(trc4->we_que_cnt, target->we_que_cnt) ;	/* scsi Response waiting count */
	}

	if ( hfcp != NULL )
	{
		HFC_4B_TO_4L(trc4->hfcp_iov_no, hfcp->iov_no) ;
		HFC_4B_TO_4L(trc4->hfcp_iov_cnt, hfcp->iov_cnt) ;
		HFC_4B_TO_4L(trc4->cmd_flags, hfcp->cmd_flags) ;		/* hfc_pkt control flag  */
		HFC_4B_TO_4L(trc4->cmd_dmacount, hfcp->data_size) ;		/* Data transfer length	   */
		HFC_4B_TO_4L(trc4->cmd_cookiecnt, hfcp->seg_cnt) ;		/* cookie count 	   */
		HFC_2B_TO_2L(trc4->xob_no, hfcp->cmd_xob) ;				/* hfc_pkt Allocation xob # */
	}

	if (id == HFC_TRC_IOVUP)
	{
		trc4->type = etc1 ;							/* 0:alloc,1:cancel		*/
		HFC_4B_TO_4L(trc4->pos, etc2) ;				/* bit position 		*/
		HFC_4B_TO_4L(trc4->cnt, etc3) ;				/* bit count			*/
	}

	if (id == HFC_TRC_RES_CHK)
	{
		HFC_4B_TO_4L(trc4->pos, etc2) ;							/* xob_out_num	 		*/
		HFC_4B_TO_4L(trc4->cnt, etc3) ;							/* xob_in_num			*/
	}
}


/*
 * Function:    hfc_stra_trc5
 *
 * Purpose:     
 *
 * Arguments:   
 *  trc_wk     - 
 *  id         - 
 *  sub_id     - 
 *  ap         - Pointer to adap_info
 *  target     - Pointer to target_info 
 *  hfcp       - Pointer to hfc_pkt 
 *  etc1       - 
 *  etc2       - 
 *  etc3       - 
 *
 * Returns:     
 *
 * Notes:       
 */
void hfc_stra_trc5( uchar	*trc_wk,
					uchar	id,
					uchar	sub_id,
					struct	adap_info *ap,
					struct	target_info *target,
					struct	hfc_pkt *hfcp,
					unsigned long long	etc1,
					unsigned long long	etc2,
					unsigned long long	etc3)
{
	struct stra_trc5 *trc5 = (struct stra_trc5 *)trc_wk;
	ushort	xob_no ;
	uint	d_scsi_id;

	/*-- etc1 : NULL	  --*/
	/*-- etc2 : type --*/
	/*-- etc3 : NULL --*/
	if( ap != NULL )
	{
		trc5->xob_outp			= ap->fw_init_p->xob_outp ;;
		HFC_2B_TO_2L(trc5->xob_no, ap->xob_no) ;
		trc5->xob_exec_cnt		= ap->xob_exec_cnt ;
		trc5->xob_wait_exec_cnt = ap->xob_wait_exec_cnt ;

		xob_no = ap->xob_no ;
		if (sub_id == 0x10)				
		{								
			if( xob_no == 0 )
				xob_no = ap->xob_max - 1 ;
			else
				xob_no-- ;
		}

		HFC_4B_TO_4L(trc5->fcp_cntl, *(uint *) &(ap->xob[xob_no].fcp_cmd.fcp_cntl)) ;
		HFC_4B_TO_4L(trc5->fcp_dl, ap->xob[xob_no].fcp_cmd.fcp_dl) ;
		HFC_MEMCPY(trc5->cdb,ap->xob[xob_no].fcp_cmd.fcp_cdb,16) ;
		HFC_MEMCPY(trc5->xob,(uchar *)&ap->xob[xob_no],48) ;
	}

	if ( target != NULL )
	{
		d_scsi_id = (uint)target->scsi_id;
		HFC_4B_TO_4L(trc5->d_scsi_id, d_scsi_id) ;		/* target  scsi_id		*/
		HFC_2B_TO_2L(trc5->wx_que_cnt, target->wx_que_cnt) ;	/* scsi start waiting count */
		HFC_2B_TO_2L(trc5->we_que_cnt, target->we_que_cnt) ;	/* scsi response waiting count */
	}
}


